--
--	Grail NPCs
--	Written by scott@mithrandir.com
--
--	Version History
--		Stopped keeping history as it was not maintained.
--
--	Each NPC value is a table that can contain:
--		[1]	code information (see below) like map location
--		[2] optional friendly notes
--		[3] optional faction association
--
--	NPC Codes
--		A:npcId			npcId that is what Blizzard returns for this alias NPC
--		Created			indicates item is created by player
--		D:<npc list>	comma separated list of NPC IDs that drop this item
--		H<holidayCode>	holidayCode is a single character indicating the holiday the NPC is available
--		K:<quest list>	comma separated list of quest IDs for which this is killed
--		Mailbox			indicates item in a mailbox (any map area)
--		Mailbox<mapId>	indicates item in a mailbox in the specified map area
--		N:npcId			npcId whose name is to be used for this NPC
--		Near			indicates the NPC is nearby (any map area)
--		Near<mapId>		indicates the NPC is nearby in the specified map area
--		Preowned		indicates item is already owned
--		Q:<quest list>	comma separated list of quest IDs to which this is associated
--		Self			special NPC indicator for Self (the player)
--		X				indicates NPC is in heroic only
--		Z<mapId>		indicates NPC found in the map area
--		anything else should be the format (without spaces):
--			mapId [mapLevel] : xx.xx , yy.yy > realMapId
--		the "[mapLevel]" is only required for maps with levels, most do not need it
--		the "> realMapId" indicates the coordinates are in a map that contains the realMap...this allows an outer map to show a point for maps that are contained within
--
--	Known issues
--
--	Maps
--
--		947		Azeroth				World
--		1411	Durotar				Zone	Kalimdor
--		1412	Mulgore				Zone	Kalimdor
--		1413	The Barrens			Zone	Kalimdor
--		1414	Kalimdor			Cont	Azeroth
--		1415	Eastern Kingdoms	Cont	Azeroth
--		1416	Alterac Mountains	Zone	Eastern Kingdoms
--		1417	Arathi Highlands	Zone	Eastern Kingdoms
--		1418	Badlands			Zone	Eastern Kingdoms
--		1419	Blasted Lands		Zone	Eastern Kingdoms
--		1420	Tirisfal Glades		Zone	Eastern Kingdoms
--		1421	Silverpine Forest	Zone	Eastern Kingdoms
--		1422	Western Plaguelands	Zone	Eastern Kingdoms
--		1423	Eastern Plaguelands	Zone	Eastern Kingdoms
--		1424	Hillsbrad Foothills	Zone	Eastern Kingdoms
--		1425	The Hinterlands		Zone	Eastern Kingdoms
--		1426	Dun Morogh			Zone	Eastern Kingdoms
--		1427	Searing Gorge		Zone	Eastern Kingdoms
--		1428	Burning Steppes		Zone	Eastern Kingdoms
--		1429	Elwynn Forest		Zone	Eastern Kingdoms
--		1430	Deadwind Pass		Zone	Eastern Kingdoms
--		1431	Duskwood			Zone	Eastern Kingdoms
--		1432	Loch Modan			Zone	Eastern Kingdoms
--		1433	Redridge Mountains	Zone	Eastern Kingdoms
--		1434	Stranglethorn Vale	Zone	Eastern Kingdoms
--		1435	Swamp of Sorrows	Zone	Eastern Kingdoms
--		1436	Westfall			Zone	Eastern Kingdoms
--		1437	Wetlands			Zone	Eastern Kingdoms
--		1438	Teldrassil			Zone	Kalimdor
--		1439	Darkshore			Zone	Kalimdor
--		1440	Ashenvale			Zone	Kalimdor
--		1441	Thousand Needles	Zone	Kalimdor
--		1442	Stonetalon Mountains Zone	Kalimdor
--		1443	Desolace			Zone	Kalimdor
--		1444	Feralas				Zone	Kalimdor
--		1445	Dustwallow Marsh	Zone	Kalimdor
--		1446	Tanaris				Zone	Kalimdor
--		1447	Azshara				Zone	Kalimdor
--		1448	Felwood				Zone	Kalimdor
--		1449	Un'Goro Crater		Zone	Kalimdor
--		1450	Moonglade			Zone	Kalimdor
--		1451	Silithus			Zone	Kalimdor
--		1452	Winterspring		Zone	Kalimdor
--		1453	Stormwind City		Zone	Eastern Kingdoms
--		1454	Orgrimmar			Zone	Kalimdor
--		1455	Ironforge			Zone	Eastern Kingdoms
--		1456	Thunder Bluff		Zone	Kalimdor
--		1457	Darnassus			Zone	Kalimdor
--		1458	Undercity			Zone	Eastern Kingdoms
--		1459	Alterac Valley		Zone	Azeroth
--		1460	Warsong Gulch		Zone	Azeroth
--		1461	Arathi Basin		Zone	Azeroth
--		1463	Eastern Kingdoms	Cont	(how differ from 1415?)
--		1464	Kalimdor			Cont 	(how differ from 1414?)
--
--	Dungeon entrances:
--		Ahn'Qiraj			1451:29.06,93.46
--		Blackfathom Deeps	1440:14.09,14.87
--		Blackrock Depths	1427:34.57,84.04	1428:31.86,50.45
--		Blackrock Spire		1427:34.57,84.04	1428:31.86,50.45
--		Deeprun Tram
--			Ironforge end	1455:76.19,51.00
--			Stormwind end	1453:51.77,12.08
--		Dire Maul			1444:59.12,45.18
--		Maraudon			1443:29.86,62.53
--		Ragefire Chasm		1454:52.76,48.99
--		Razorfen Downs		1413:49.26,98.08
--		Razorfen Kraul		1413:42.63,90.14
--		Scholomance			1422:69.93,74.01
--		Shadowfang Keep		1421:44.82,67.83
--		Stratholme			1423:30.85,20.08	1423:47.91,23.87
--		The Deadmines		1436:40.68,79.58
--		The Temple of Atal'Hakkar
--							1435:68.81,59.27
--		The Wailing Caverns	1414:52.40,55.19
--		Uldaman	1418:44.54,12.22 1418:65.03,43.51
--		Zul'Farrak			1446:38.72,20.00
--		Zul'Gurub			1434:53.85,17.58
--
--	UTF-8 file
--
Grail_NPCs_File_Version = 015

if Grail.npcsVersionNumber >= Grail_NPCs_File_Version then return end
Grail.npcsVersionNumber = Grail_NPCs_File_Version

Grail.npcs = {}

local _, release, _, interface = GetBuildInfo()
release = tonumber(release)
interface = tonumber(interface)

local G = Grail.npcs

if release >= 0 then
G[48]={'1431:79.60,68.40 1431:80.80,73.80'}	-- Skeletal Warrior
G[97]={'1429:24.19,88.43 1429:26.91,86.46 1429:30.94,87.51 1429:30.41,82.26 1429:66.94,47.17 1429:64.31,38.11 1429:70.53,40.21'}	-- Riverpaw Runt
G[100]={'1429:26.39,93.49 1429:27.25,92.63 1429:27.39,91.41'}	-- Gruff Swiftbite
G[116]={'1429:69.35,79.09 1429:68.40,78.00 1429:70.61,78.06 1429:23.40,53.10 1429:71.03,80.06 1429:68.60,80.81 1429:86.6,79.50 1429:52.80,60.80 1429:54.40,61.00 1429:50.60,83.00 1429:47.40,73.80 1429:28.60,58.40 1429:31.60,58.80 1429:32.00,65.60'}	-- Defias Bandit
G[126]={'1436:52.59,10.60 1436:56.92,10.51 1436:44.76,9.84 1436:41.67,12.23'}
G[127]={'1436:34.37,84.46 1436:32.34,82.29 1436:29.71,78.69 1436:28.23,71.64 1436:27.45,69.07'}
G[171]={'1436:36.48,18.54 1436:31.67,26.24 1436:29.22,32.76 1436:26.92,47.68 1436:27.02,52.14'}
G[196]={'FA 1429:48.94,40.16'}	-- Eagan Peltskinner
G[197]={'FA 1429:48.92,41.60'}	-- Marshal McBride
G[198]={'FA 1429:49.66,39.40'}	-- Khelden Bremen
G[203]={'1431:79.80,69.40 1431:81.00,72.80'}	-- Skeletal Mage
G[205]={'1431:60.60,38.4 1431:63.40,52.80 1431:65.40,67.80 1431:60.80,77.40'}	-- Nightbane Dark Runner
G[215]={'1431:21.90,63.80'}	-- Defias Night Runner
G[218]={'1431:14.40,44.60 1431:22.00.46.20 1431:20.60,54.20'}	-- Grave Robber
G[233]={'FA 1436:56.04,31.23'}
G[234]={'FA 1436:56.32,47.52'}	-- Gryan Stoutmantle
G[235]={'FA 1436:56.41,30.52'}
G[237]={'FA 1436:59.95,19.36'}
G[238]={'FA 1436:59.92,19.41'}
G[239]={'FA 1436:44.63,80.25'}
G[240]={'FA 1429:42.11,65.93'}	-- Marshal Dughan
G[241]={'FA 1429:42.14,67.25'}	-- Remy "Two Times"
G[244]={'FA 1429:34.66,84.48'}	-- Ma Stonefield
G[246]={'FA 1429:34.49,84.26'}	-- Auntie Bernice Stonefield
G[247]={'FA 1429:43.13,85.72'}	-- Billy Maclure
G[248]={'FA 1429:34.94,83.87'}	-- Gramma Stonefield
G[251]={'FA 1429:43.15,89.62'}	-- Maybell Maclure
G[252]={'FA 1429:29.84,86.01'}	-- Tommy Joe Stonefield
G[253]={'FA 1429:43.32,65.71'}	-- William Pestle
G[255]={'FA 1429:43.10,85.50'}	-- Gerard Tiller
G[261]={'FA 1429:73.97,72.19'}	-- Guard Thomas
G[263]={'FA 1431:71.92,46.42'}	-- Lord Ello Ebonlocke
G[264]={'FA 1431:73.55,46.89'}	-- Commander Althea Ebonlocke
G[265]={'FA 1431:75.82,45.31'}
G[266]={'FA 1433:26.48,45.35'}	-- Wiley the Black
G[267]={'FA 1431:72.55,46.86'}	-- Clerk Daltry
G[268]={'FA 1431:72.60,47.62'}	-- Sirra Von'Indi
G[270]={'FA 1431:71.93,47.75','Walks in area'}	-- Councilman Millstipe
G[272]={'FA 1431:73.75,43.48','Sometimes comes out of kitchen'}
G[273]={'FA 1431:74.08,44.71 1431:73.78,44.49'}
G[276]={'FA 1431:79.79,48.06'}
G[278]={'FA 1429:79.46,68.79'}	-- Sara Timberlain
G[279]={'FA 1453:56.19,64.58'}	-- Morgan Pestle
G[288]={'FA 1431:18.30,56.58','Circles well'}
G[289]={'FA 1431:28.10,31.47'}
G[294]={'FA 1429:84.61,69.38'}	-- Marshal Haggard
G[295]={'FA 1429:43.77,65.81'}	-- Innkeeper Farley
G[297]={'FA 1453:29.53,61.93'}	-- Caretaker Folsom
G[302]={'FA 1431:81.98,59.10'}
G[311]={'FA 1431:7.78,34.08'}
G[313]={'FA 1429:65.22,69.71','Top of tower'}	-- Theocritus
G[328]={'FA 1429:43.25,66.19'}	-- Zaldimar Wefhellt
G[331]={'FA 1453:38.22,81.85'}	-- Maginor Dumas
G[332]={'FA 1453:75.79,59.86'}	-- Master Mathias Shaw
G[338]={'FA 1453:41.51,64.36'}	-- Mazen Mac'Nadir
G[341]={'FA 1433:32.13,48.64'}	-- Foreman Oslow
G[342]={'FA 1433:21.86,46.33'}	-- Martie Jainrose
G[343]={'FA 1433:22.68,43.85'}	-- Chef Breanna
G[344]={'FA 1433:29.99,44.45'}	-- Magistrate Solomon
G[346]={'FA 1433:26.48,43.97'}	-- Barkeep Daniels
G[349]={'FA 1433:28.38,12.57'}
G[352]={'FA 1453:66.28,62.13'}	-- Dungar Longdrink
G[375]={'FA 1429:49.81,39.50'}	-- Priestess Anetta
G[376]={'FA 1453:38.57,26.06'}	-- High Priestess Laurena
G[377]={'FA 1429:43.28,65.71'}	-- Priestess Josetta
G[379]={'FA 1433:26.91,44.82','Walks around Inn'}	-- Darcy
G[381]={'FA 1433:27.72,47.36'}	-- Dockmaster Baren
G[382]={'FA 1433:33.51,48.98'}	-- Marshal Marris
G[391]={'1436:35.44,86.13 1436:31.98,82.12 1436:29.88,78.56 1436:28.74,72.32 1436:26.07,65.12'}
G[392]={'FA 1436:30.02,86.01'}
G[415]={'FA 1433:30.97,47.27'}	-- Verner Osgood
G[429]={'1433:79.80,44.80 1433:80.00.49.20'}	-- Shadowhide Darkweaver
G[431]={'1433:79.80,49.00 1433:81.80,49.60'}	-- Shadowhide Slayer
G[432]={'1433:80.06,35.20 1433:76.60,38.40 1433:82.60,42.40 1433:77.40,47.40 1433:80.80,44.80'}	-- Shadowhide Brute
G[433]={'1433:58.80,40.60 1433:65.60,42.60 1433:75.60,42.20 1433:71.00,49.40 1433:77.80,47.40 1433:70.40,58.60 1433:79.80,54.60'}	-- Shadowhide Gnoll
G[434]={'1433:69.20,41.80 1433:77.40,43.20 1433:73.20,53.40 1433:80.40,53.20 1433:73.60,53.80'}	-- Rabid Shadowhide Gnoll
G[448]={'1429:25.15,93.75 1429:27.14,92.63 1429:25.63,90.16'}	-- Hogger
G[456]={'1436:35.86,19.56 1436:38.95,14.55 1436:43.88,10.51 1436:47.69,10.73'}
G[458]={'1436:26.40,62.13 1436:27.08,56.22 1436:26.86,48.94 1436:27.78,39.50 1436:29.17,33.58 1436:31.54,27.41'}
G[459]={'FA 1429:49.87,42.65'}	-- Drusilla La Salle
G[460]={'FA 1426:28.65,66.14'}	-- Alamar Grimm
G[461]={'FA 1453:25.29,78.22'}	-- Demisette Cloyce
G[464]={'FA 1433:15.27,71.47 1433:17.37,69.55','Walks between spots'}	-- Guard Parker
G[466]={'FA 1453:63.99,75.34'}	-- General Marcus Jonathan
G[467]={'FA 1436:55.68,47.51'}
G[469]={'FA 1434:38.04,3.01'}
G[474]={'1429:73.14,49.60 1429:74.40,53.80 1429:76.60,53.60 1429:76.60,49.80 1429:87.08,78.82 1429:50.60,82.80 1429:52.80,59.20 1429:29.80,61.00'}	-- Defias Rogue Wizard
G[478]={'1429:24.46,91.58 1429:27.26,90.14 1429:24.54,84.49 1429:26.91,83.04 1429:67.82,51.25 1429:66.77,43.62 1429:67.91,38.37 1429:71.41,37.45'}	-- Riverpaw Outrunner
G[482]={'FA 1453:59.91,64.18','Upstairs'}	-- Elling Trias
G[491]={'FA 1436:56.99,47.17'}
G[513]={'1436:44.05,9.12 1436:40.79,12.25 1436:37.86,15.86 1436:35.71,19.62 1436:32.74,23.77 1436:30.07,31.41'}
G[514]={'FA 1429:41.71,65.55'}	-- Smith Argus
G[515]={'1436:56.68,9.06 1436:52.21,9.12 1436:48.37,10.15 1436:45.04,8.64'}
G[517]={'1436:34.96,84.33 1436:29.28,75.99 1436:28.28,71.08 1436:26.32,60.67 1436:26.96,54.29'}
G[519]={'1436:53.96,11.70 1436:45.11,9.56 1436:37.68,16.29 1436:32.51,23.69 1436:27.53,40.11 1436:27.19,54.72 1436:28.92,73.93 1436:33.78,83.68'}	-- Slark
G[520]={'1436:53.96,11.70 1436:45.11,9.56 1436:37.68,16.29 1436:32.51,23.69 1436:27.53,40.11 1436:27.19,54.72 1436:28.92,73.93 1436:33.78,83.68'}	-- Brack
G[523]={'FA 1436:56.55,52.65'}	-- Thor
G[533]={'1431:62.60,72.20'}	-- Nightbane Shadow Weaver
G[568]={'1433:76.80,42.80'}	-- Shadowhide Warrior
G[576]={'FA 1431:73.75,47.23'}
G[579]={'1433:75.60,32.60 1433:75.00,42.60 1433:77.40,42.80 1433:81.80,48.80 1433:75.80,53.60'}	-- Shadowhide Assassin
G[620]={'1436:56.19,31.66'}	-- Chicken - Note probably use any chicken, but this position is commonest
G[633]={'FA 1431:75.34,48.72'}
G[639]={'947:0.00,0.00 1436:40.68,79.58>947','The Deadmines'}	-- Edwin VanCleef
G[656]={'FA 1453:65.43,21.19'}	-- Wilder Thistlenettle
G[658]={'FA 1426:29.93,71.21'}	-- Sten Stoutarm
G[661]={'FA 1431:75.32,49.02'}
G[663]={'FA 1431:75.30,48.04'}
G[703]={'1433:80.20,37.10'}	-- Lieutenant Fangore
G[713]={'FA 1426:29.71,71.25'}	-- Balir Frosthammer
G[714]={'FA 1426:22.60,71.43'}	-- Talin Keeneye
G[715]={'1434:35.66,10.81'}	-- Hemet Nesingwary
G[716]={'1434:35.66,10.53'}	-- Barnil Stonepot
G[717]={'1434:35.62,10.62'}	-- Ajeck Rouack
G[718]={'1434:35.55,10.55'}	-- Sir S. J. Erlgadin
G[733]={'FA 1434:38.02,3.33'}
G[737]={'1434:27.00,77.13','Upstairs'}	-- Kebok
G[738]={'FA 1434:40.05,8.26','Gives quest when on patrol and is saved from attackers.'}	-- Private Thorsen changed to position where gives quest
G[739]={'FA 1434:37.83,3.56'}
G[770]={'FA 1434:37.74,3.30'}	-- Corporal Kaleb
G[771]={'1431:16.00,34.40 1431:17.60,37.60'}	-- Commander Felstrom
G[773]={'1434:26.95,77.21','Upstairs'}	-- Krazek
G[786]={'FA 1426:25.08,75.71'}	-- Grelin Whitebeard
G[820]={'FA 1436:56.67,47.35'}
G[821]={'FA 1436:56.42,47.62'}	-- Captain Danuvin
G[823]={'FA 1429:48.16,42.95'}	-- Deputy Willem
G[836]={'FA 1426:28.77,66.38'}	-- Durnan Furcutter
G[837]={'FA 1426:28.60,66.39'}	-- Branstock Khalder
G[840]={'FA 1431:73.27,32.61','Walks between here and town'}	-- Watcher Backus
G[859]={'FA 1433:26.25,46.56'}	-- Guard Berton
G[878]={'FA 1436:53.98,52.97'}	-- Scout Galiaan
G[888]={'FA 1431:45.12,67.02'}
G[893]={'FA 1431:7.71,33.33'}
G[895]={'FA 1426:29.17,67.46'}	-- Thorgas Grimson
G[898]={'1431:57.40,31.00 1431:66.20,41.60 1431:61.80,52.40'}	-- Nightbane Worgen
G[900]={'FA 1433:29.70,44.26'}	-- Bailiff Conacher
G[903]={'FA 1433:31.54,57.87'}	-- Guard Howe
G[911]={'FA 1429:50.24,42.28'}	-- Llane Beshere
G[912]={'FA 1426:28.83,67.24'}	-- Thran Khorman
G[913]={'FA 1429:41.09,65.77'}	-- Lyria Du Lac
G[914]={'FA 1453:78.13,47.63'}	-- Ander Germaine
G[915]={'FA 1429:50.32,39.92'}	-- Jorik Kerridan
G[916]={'FA 1426:28.37,67.51'}	-- Solm Hargrin
G[917]={'FA 1429:43.87,65.93'}	-- Keryn Sylvius
G[918]={'FA 1453:74.64,52.80'}	-- Osborne the Night Man
G[920]={'1431:73.00,75.00 1431:74.00,79.60 1431:61.00,81.60 1431:63.20,83.20'}	-- Nightbane Tainted One
G[925]={'FA 1429:50.43,42.13'}	-- Brother Sammuel
G[926]={'FA 1426:28.83,68.33'}	-- Bromos Grummner
G[927]={'FA 1429:41.10,66.04'}	-- Brother Wilhelm
G[928]={'FA 1453:37.16,33.31'}	-- Lord Grayson Shadowbreaker
G[944]={'FA 1426:28.71,66.37'}	-- Marryk Nurribit
G[947]={'1433:76.00,29.40 1433:77.20,39.20 1433:76.80,40.60 1433:82.40,49.60 1433:82.80,54.00'}	-- Rohh the Silent
G[951]={'FA 1429:49.61,40.42'}	-- Brother Paxton
G[952]={'FA 1429:49.47,41.58', 'Top of tower'}	-- Brother Neals
G[963]={'FA 1429:24.23,74.46'}	-- Deputy Rainer
G[986]={'FH 1435:48.00,57.80'}
G[1035]={'1437:47.48,46.83'}
G[1068]={'FH 1418:2.91,45.61'}	-- Gorn
G[1070]={'FA 1433:30.74,60.00'}	-- Deputy Feldon
G[1071]={'FA 1437:49.81,18.26'}	-- Longbraid the Grim
G[1073]={'FA 1437:50.05,18.17'}	-- Ashlan Stonesmirk
G[1074]={'FA 1437:49.67,18.24'}	-- Motley Garmason
G[1075]={'FA 1437:49.91,18.23'}	-- Rhag Garmason
G[1076]={'FA 1437:38.91,52.33'}
G[1077]={'FA 1437:38.81,52.37'}
G[1078]={'FA 1437:38.26,50.80','Walks around'}
G[1089]={'FA 1432:22.07,73.12'}
G[1090]={'FA 1432:23.47,74.53'}
G[1091]={'FA 1432:23.53,76.40'}
G[1092]={'FA 1432:23.23,73.69'}
G[1093]={'FA 1432:46.03,13.62'}
G[1105]={'FA 1432:37.23,47.40 1432:36.99,47.03','Can be inside or outside building'}	-- Jern Hornhelm
G[1139]={'FA 1432:34.60,44.47 1432:34.69,43.18','Can be inside or outside building'}	-- Magistrate Bluntnose
G[1141]={'FA 1453:41.50,89.38'}	-- Angus Stern
G[1154]={'FA 1432:81.76,61.67'}
G[1156]={'FA 1432:81.74,64.14'}
G[1182]={'FA 1443:66.52,7.90'}	-- Brother Anton
G[1187]={'FA 1432:83.48,65.42'}
G[1196]={'1431:28.80,30.78'}
G[1212]={'FA 1453:39.10,27.85'}	-- Bishop Farthing
G[1217]={'FA 1437:10.58,60.58'}
G[1226]={'FA 1426:47.35,52.19'}	-- Maxan Anvol
G[1228]={'FA 1426:47.50,52.07'}	-- Magis Sparkmantle
G[1229]={'FA 1426:47.36,52.65'}	-- Granis Swiftaxe
G[1231]={'FA 1426:45.81,53.04'}	-- Grif Wildheart
G[1232]={'FA 1426:47.60,52.07'}	-- Azar Stronghammer
G[1234]={'FA 1426:47.57,52.61'}	-- Hogral Bakkan
G[1239]={'FA 1437:10.90,59.63'}
G[1242]={'FA 1437:8.35,58.55'}
G[1243]={'FA 1426:40.69,65.12'}	-- Hegnar Rumbleshot
G[1244]={'FA 1437:56.34,40.42'}	-- Rethiel the Greenwarden
G[1252]={'FA 1426:46.72,53.82'}	-- Senir Whitebeard
G[1254]={'FA 1426:69.08,56.33'}	-- Foreman Stonebrow
G[1265]={'FA 1426:63.08,49.85'}	-- Rudra Amberstill
G[1266]={'FA 1426:34.58,51.65'}	-- Tundra MacGrann
G[1267]={'FA 1426:46.82,52.36'}	-- Ragnar Thunderbrew
G[1268]={'FA 1426:45.89,49.37'}	-- Ozzie Togglevolt
G[1269]={'FA 1426:45.85,49.36'}	-- Razzle Sprysprocket
G[1274]={'FA 1455:39.56,57.50'}	-- Senator Barin Redstone
G[1284]={'FA 1453:39.59,27.20'}	-- Archbishop Benedictus
G[1309]={'FA 1453:41.57,76.35'}	-- Wynne Larson
G[1323]={'FA 1453:74.30,47.24'}	-- Osric Strang
G[1340]={'FA 1432:34.24,47.73','Walks through town'}
G[1342]={'FA 1432:25.44,10.39'}
G[1343]={'FA 1432:24.76,18.40'}
G[1344]={'FA 1432:65.93,65.61'}
G[1345]={'FA 1432:64.90,66.65'}
G[1356]={'FA 1455:74.64,11.72'}	-- Prospector Stormpike
G[1365]={'HV FA 1455:30.27,59.37'}	-- Goli Krumn
G[1373]={'FA 1426:47.63,52.65','In basement'}	-- Jarven Thunderbrew
G[1374]={'FA 1426:30.19,45.73'}	-- Rejold Barleybrew
G[1375]={'FA 1426:30.19,45.53'}	-- Marleth Barleybrew
G[1376]={'FA 1426:50.43,49.08'}	-- Beldin Steelgrill
G[1377]={'FA 1426:49.62,48.61'}	-- Pilot Stonegear
G[1378]={'FA 1426:49.43,48.41'}	-- Pilot Bellowfiz
G[1379]={'FA 1432:52.21,69.44'}
G[1416]={'FA 1453:51.74,12.10'}	-- Grimand Elmore
G[1422]={'FA 1434:37.66,3.39'}	-- Corporal Sethman
G[1427]={'FA 1453:55.11,56.21'}	-- Harlan Bagley
G[1428]={'FA 1453:49.65,55.63'}	-- Rema Schneider
G[1429]={'FA 1453:42.53,76.21'}	-- Thurman Schneider
G[1431]={'FA 1453:52.47,67.61'}	-- Suzetta Gallina
G[1432]={'FA 1453:56.99,63.52'}	-- Renato Gallina
G[1435]={'FA 1453:26.44,78.61','In basement'}	--Zardeth of the Black Claw
G[1439]={'FA 1453:75.24,31.67'}	-- Lord Baurles K. Wishock
G[1440]={'FA 1453:74.18,7.47'}	-- Milton Sheaf
G[1442]={'FH 1435:47.74,55.19','Upstairs'}	-- Helgrum the Swift
G[1443]={'FH 1435:47.93,54.78','Upstairs'}	-- Fel'zerul
G[1444]={'FA 1453:45.69,38.41'}	-- Brother Kristoff
G[1449]={'1434:35.28,60.32'}	-- Witch Doctor Unbagwa
G[1470]={'FA 1432:37.07,49.37', 'Underground'}
G[1495]={'FH 1420:65.49,60.26'}	-- Deathguard Linnea
G[1496]={'FH 1420:58.20,51.45'}	-- Deathguard Dillinger
G[1497]={'FH 1420:68.20,41.91'}	-- Gunther Arcanus
G[1498]={'FH 1458:84.09,17.46'}	-- Bethor Iceshard
G[1499]={'FH 1420:61.26,50.84'}	-- Magistrate Sevren
G[1500]={'FH 1420:61.72,52.29'}	-- Coleman Farthing
G[1515]={'FH 1420:60.58,51.76'}	-- Executor Zygand
G[1518]={'FH 1420:59.45,52.39'}	-- Apothecary Johaan
G[1519]={'FH 1420:40.92,54.17'}	-- Deathguard Simmer
G[1520]={'1420:46.00,33.20 1420:49.60,37.60 1420:44.80,33.80 1420:46.80,42.80 1420:49.20,44.20'}	-- Rattlecage Soldier
G[1521]={'FH 1420:61.89,52.72','Upstairs bedroom'}	-- Gretchen Dedmar
G[1522]={'1420:47.60,31.60 1420:45.40,3500 1420:49.80,36.80 1420:49.20,41.80'}	-- Darkeye Bonecaster
G[1523]={'1420:47.00,28.60 1420:45.00,31.40 1420:50.00,33.20 1420:47.00,35.00'}	-- Cracked Skull Soldier
G[1560]={'FH 1420:61.58,52.60'}	-- Yvette Farthing
G[1568]={'FH 1420:30.22,71.65'}	-- Undertaker Mordo
G[1569]={'FH 1420:30.84,66.19'}	-- Shadow Priest Sarvis
G[1570]={'FH 1420:32.15,66.01'}
G[1572]={'FA 1432:33.94,50.96'}	-- Thorgrum Borrelson
G[1573]={'FA 1455:55.49,47.77'}	-- Gryth Thurden
G[1646]={'FA 1453:49.18,30.27'}	-- Baros Alexston
G[1652]={'FH 1420:60.93,52.01'}	-- Deathguard Burgess
G[1661]={'FH 1420:30.86,66.05'}	-- Novice Elreth
G[1681]={'FA 1432:37.02,47.80 1432:37.26,46.93','Can be inside or outside building'}	-- Brock Stoneseeker
G[1694]={'FA 1426:50.08,49.41'}	-- Loslor Rudge
G[1719]={'FA 1453:41.10,58.10'}	-- Warden Thelwater
G[1721]={'FA 1453:73.60,46.58 1453:68.43,39.60 1453:66.77,45.41 1453:71.03,49.00'}	-- Nikova Raskol
G[1733]={'FA 1453:26.53,78.67'}	-- Zggi
G[1740]={'1420:31.64,65.60','Pacing'}
G[1748]={'FA 1453:78.21,17.98','Moves during scripted event'}	-- Highlord Bolvar Fordragon
G[1749]={'FA 1453:78.11,17.74'}	-- Lady Katrana Prestor
G[1776]={'1435:25.92,31.58'}
G[1854]={'FA 1422:52.20,83.60'}	-- High Priest Thel'danis
G[1872]={'FA 1426:46.02,51.67'}	-- Tharek Blackstone
G[1931]={'FH 1420:61.97,51.29','In basement'}	-- Captured Scarlet Zealot
G[1937]={'FH 1421:42.80,40.87'}	-- Apothecary Renferrel
G[1938]={'FH 1421:44.20,39.78','Walks nearby'}	-- Dalar Dawnweaver
G[1939]={'1421:65.69,28.26 1421:69.60,36.00 1421:67.00,24.80 1421:67.80,24.80'}	-- Rot Hide Brute
G[1940]={'1421:64.60,23.60 1421:65.80,25.20 1421:65.80,28.80 1421:67.80,25.80 1421:68.00,34.40 1421:67.40,35.60'}	-- Rot Hide Plague Weaver
G[1942]={'1421:65.00,24.80 1421:66.66,24.90 1421:65.46,27.55'}	-- Rot Hide Savage
G[1943]={'1421:65.40,24.60 1421:66.00,24.60 1421:65.60,25.80'}	-- Raging Rot Hide
G[1944]={'1421:65.00,21.40 1421:65.60,23.00 1421:67.00,24.80 1421:66.00,27.00'}	-- Rot Hide Bruiser
G[1950]={'FH 1421:53.46,13.43'}	-- Rane Yorick
G[1951]={'FH 1421:53.43,12.59','Upstairs'}	-- Quinn Yorick
G[1952]={'FH 1421:43.42,40.86','Underground'}	-- High Executor Hadrec
G[1959]={'FA 1426:86.28,48.82'}	-- Mountaineer Barleybrew
G[1960]={'FA 1426:83.89,39.19'}	-- Pilot Hammerfoot
G[1963]={'FA 1432:34.83,49.28'}	-- Vidra Hearthstove
G[1965]={'FA 1426:33.49,71.85'}	-- Mountaineer Thalos
G[1977]={'FA 1426:68.67,55.96'}	-- Senator Mehr Stonehallow
G[1978]={'FH 1421:56.19,9.18'}	-- Deathstalker Erland
G[1992]={'FA 1438:57.73,45.05','Walks in small area'}	-- Tarindrella
G[2050]={'FH 1458:62.02,42.77'}	-- Raleigh Andrean
G[2055]={'FH 1458:48.81,69.29','Moves near here'}	-- Master Apothecary Faranell
G[2057]={'FA 1432:52.19,69.33'}
G[2058]={'FH 1421:46.50,74.37'}	-- Deathstalker Faerleia
G[2077]={'FA 1438:59.92,42.48'}	-- Melithar Staghelm
G[2078]={'FA 1438:55.95,57.27'}	-- Athridas Bearmantle
G[2079]={'FA 1438:58.69,44.27'}	-- Conservator Ilthalaine
G[2080]={'FA 1438:60.90,68.49'}	-- Denalan
G[2081]={'FA 1438:56.00,59.53'}	-- Sentinel Kyra Starsong
G[2082]={'FA 1438:57.81,41.66'}	-- Gilshalan Windwalker
G[2083]={'FA 1438:56.08,57.72'}	-- Syral Bladeleaf
G[2086]={'FA 1437:10.10,56.89'}
G[2092]={'FA 1455:72.73,94.02'}	-- Pilot Longbeard
G[2093]={'FA 1437:49.92,39.38'}	-- Einar Stonegrip
G[2094]={'FA 1437:8.50,55.68'}	-- James Halloran
G[2096]={'FA 1437:11.48,52.14'}
G[2097]={'FA 1437:10.85,55.89'}
G[2104]={'FA 1437:9.86,57.49','Top of keep'}
G[2107]={'FA 1438:66.26,58.52'}	-- Gaerolas Talvethren
G[2111]={'FA 1437:11.79,57.99'}
G[2119]={'FH 1420:32.68,65.56'}	-- Dannal Stern
G[2121]={'FH 1421:43.98,40.93'}	-- Shadow Priest Allister
G[2122]={'FH 1420:32.53,65.66'}	-- David Trias
G[2123]={'FH 1420:31.11,66.03'}	-- Dark Cleric Duesten
G[2124]={'FH 1420:30.93,66.06'}	-- Isabella
G[2126]={'FH 1420:30.91,66.33'}
G[2128]={'FH 1420:61.96,52.47'}	-- Cain Firesong
G[2129]={'FH 1420:61.58,52.19'}	-- Dark Cleric Beryl
G[2130]={'FH 1420:61.75,52.00'}	-- Marion Call
G[2131]={'FH 1420:61.85,52.54'}	-- Austil de Mon
G[2150]={'FA 1438:60.40,56.18'}	-- Zenn Foulhoof
G[2151]={'FA 1438:55.80,58.32 1438:50.19,53.87 1438:52.15,56.45','Patrols the road'}	-- Moon Priestess Amara
G[2155]={'FA 1438:41.60,50.97 1438:39.01,53.22 1438:37.98,54.53','Patrols the road'}	-- Sentinel Shayla Nightbreeze
G[2198]={'FA 11453:51.61,29.05 1453:52.63,31.59 1453:49.46,35.17 1453:46.54,37.28 1453:44.15,39.78 1453:37.45,45.03 1453:36.37,50.95 1453:31.77,60.20 1453:33.61,63.76 1453:34.93,68.68 1453:31.99,73.34 1453:31.47,79.97 1453:35.97,80.29 1453:41.23,80.15 1453:43.97,70.39 1453:46.35,66.16 1453:48.92,63.23 1453:52.12,60.72 1453:54.27,63.36 1453:58.92,57.77 1453:58.08,53.69 1453:60.75,52.06 1453:63.98,48.37 1453:67.38,46.37 1453:71.55,41.69 1453:67.22,40.71 1453:64.96,36.78 1453:67.98,30.45 1453:62.21,33.24 1453:56.93,31.35 1453:54.30,25.81 1453:51.62,28.41','Walks round city'}	-- Crier Goodman
G[2211]={'1420:61.94,51.41','In basement'}
G[2214]={'FH 1424:20.79,47.41'}	-- Deathstalker Lesh
G[2215]={'FH 1424:62.39,20.31'}	-- High Executor Darthalia
G[2216]={'FH 1424:61.44,19.07'}	-- Apothecary Lydon
G[2226]={'FH 1421:45.62,42.60'}	-- Karos Razok
G[2227]={'FH 1458:57.59,93.80'}	-- Sharlindra
G[2228]={'FA 1424:51.46,58.38'}	-- Lieutenant Farren Orinelle
G[2229]={'FH 1424:63.23,20.66'}	-- Krusk
G[2230]={'FH 1424:61.52,19.18'}	-- Umpi
G[2263]={'FA 1424:49.48,58.73'}	-- Marshal Redpath
G[2274]={'FH 1424:32.67,35.29'}	-- Stanley
G[2276]={'FA 1424:48.14,59.11'}	-- Magistrate Henry Maleb
G[2277]={'FA 1424:50.58,57.10'}	-- Loremaster Dibbs
G[2278]={'FH 1424:62.63,20.64'}	-- Melisara
G[2285]={'FA 1453:74.00,30.25'}	-- Count Remington Ridgewell
G[2316]={'FH 1416:59.97,43.76'}	-- Gol'dir
G[2317]={'1416:39.30,14.31'}	-- Elysa
G[2333]={'FH 1416:57.17,69.51'}	-- Henchman Valik
G[2338]={'1439:37.92,85.73 1439:37.96,87.08 1439:39.49,87.90 1439:39.53,85.19'}	-- Twilight Disciple
G[2339]={'1439:37.92,85.73 1439:37.96,87.08 1439:39.49,87.90 1439:39.53,85.19 1439:56.80,34.40'}	-- Twilight Thug
G[2382]={'FA 1424:52.43,55.96'}	-- Darren Malvew
G[2391]={'FH 1424:61.60,19.20'}
G[2410]={'FH 1424:61.61,20.85'}	-- Magus Wordeen Voidglare
G[2418]={'FH 1424:62.11,19.72'}	-- Deathguard Samsa
G[2419]={'FH 1424:62.75,20.21'}	-- Deathguard Humbert
G[2425]={'FH 1458:56.29,92.20'}	-- Varimathras
G[2429]={'FH 1424:63.87,19.66'}	-- Novice Thaivand
G[2430]={'FA 1424:51.88,58.68'}	-- Chef Jessen
G[2434]={'1424:49.60,53.60 1424:54.80,54.80 1424:50.00,61.40 1424:54.40,60.60'}	-- Shadowy Assassin
G[2437]={'FH 1424:61.50,20.93'}	-- Keeper Bel'varil
G[2438]={'FA 1424:49.43,55.53'}	-- Bartolo Ginsetti
G[2439]={'FA 1453:72.57,15.88'}	-- Major Samuelson
G[2464]={'FH 1434:32.20,28.85'}	-- Commander Aggro'gosh
G[2465]={'FH 1434:32.12,29.24'}	-- Far Seer Mok'thardin
G[2486]={'1434:27.62,76.73'}	-- Fin Fizracket
G[2487]={'1434:27.17,77.01'}	-- Fleet Master Seahorn
G[2488]={'1434:26.92,77.35'}	-- Deeg
G[2490]={'1434:28.09,76.22'}	-- First Mate Crazz
G[2491]={'1434:27.14,77.45'}	-- Whiskey Slim
G[2493]={'1434:28.59,75.90'}	-- Dizzy One-Eye
G[2494]={'1434:27.38,76.95'}
G[2495]={'1434:28.30,77.59'}	-- Drizzlik
G[2496]={'1434:27.23,76.87'}	-- Baron Revilgaz
G[2497]={'FH 1434:32.16,27.73'}	-- Nimboya
G[2498]={'1434:27.11,77.27'}
G[2500]={'1434:26.73,73.63'}
G[2501]={'1434:27.78,77.07'}	-- "Sea Wolf" MacKinley
G[2502]={'1434:26.89,73.59'}	-- "Shaky" Phillipe
G[2504]={'FA 1453:71.56,7.35'}	-- Donyal Tovald
G[2519]={'FH 1434:32.27,27.71'}	-- Kin'weelay
G[2530]={'1434:39.02,58.35'}	-- Yenniku
G[2542]={'1434:27.28,77.53'}	-- Catelyn the Blade
G[2543]={'FA 1416:18.84,78.49'}	-- Archmage Ansirem Runeweaver
G[2594]={'1434:26.70,73.61'}
G[2610]={'1417:32.29,81.36'}	-- Shakes O'Breen
G[2616]={'FA 1445:67.72,51.71'}
G[2634]={'1434:38.52,80.59'}	-- Princess Poobah
G[2640]={'1425:47.60,69.60 1425:63.80,60.00 1425:68.60,69.20'}	-- Vilebranch Witch Doctor
G[2643]={'1425:64.20,67.60 1425:68.00,72.40 1425:67.80,73.00'}	-- Vilebranch Berserker
G[2645]={'1425:59.80,70.20 1425:62.60,69.00 1425:67.00,75.40'}	-- Vilebranch Shadow Hunter
G[2648]={'1425:60.60,79.80 1425:56.60,85.60 1425:57.60,86.60 1425:62.00,81.40'}	-- Vilebranch Aman'zasi Guard
G[2670]={'1434:28.71,76.89'}	-- Xizk Goodstitch
G[2693]={'FA 1425:29.60,49.60 1425:32.00,46.00'}	-- Highvale Marksman
G[2694]={'FA 1425:31.60,47.20 1425:32.60,50.20'}	-- Highvale Ranger
G[2695]={'FA 1455:63.48,67.32'}	-- Sara Balloo
G[2696]={'FA 1417:43.24,92.64'}	-- Foggy MacKreel
G[2700]={'FA 1417:45.83,47.55'}	-- Captain Nials
G[2703]={'FH 1417:73.81,33.97'}	-- Zengu
G[2705]={'FA 1424:52.13,58.77'}	-- Brewmeister Bilger
G[2706]={'FH 1417:74.72,36.29'}	-- Tor'gan
G[2708]={'FA 1453:39.84,81.46'}	-- Archmage Malin
G[2711]={'FA 1424:50.35,59.05'}	-- Phin Odelic
G[2712]={'FA 1417:60.18,53.85'}	-- Quae
G[2713]={'FA 1417:60.24,53.92'}	-- Kinelory
G[2739]={'1418:53.03,33.95'}
G[2766]={'1417:31.83,82.66'}	-- Lolo the Lookout
G[2767]={'1417:32.79,81.39'}	-- First Mate Nilzlix
G[2768]={'1417:33.87,80.55'}	-- Professor Phizzlethorpe
G[2769]={'1417:34.01,80.79'}	-- Captain Steelgut
G[2770]={'FH 1424:61.87,19.58'}	-- Tallow
G[2771]={'FH 1417:74.24,33.91'}	-- Drum Fel
G[2772]={'FH 1417:74.04,33.07'}	-- Korin Fel
G[2774]={'1417:33.86,80.46'}	-- Doctor Draxlegauge
G[2784]={'FA 1455:39.08,56.19'}	-- King Magni Bronzebeard
G[2785]={'1418:51.39,76.87'}	-- Theldurin the Lost
G[2786]={'FA 1455:50.82,5.64'}	-- Gerrig Bonegrip
G[2787]={'FH 1417:74.53,35.64'}	-- Zaruk
G[2788]={'FA 1417:46.20,47.75'}	-- Apprentice Kryten
G[2789]={'FA 1417:46.65,47.01'}	-- Skuerto
G[2790]={'FA 1455:39.02,88.03 1455:38.74,87.03 1455:39.06,87.12'}	-- Grand Mason Marblesten
G[2792]={'FH 1417:72.63,33.93'}	-- Gor'mul
G[2817]={'1418:42.39,52.92'}	-- Rigglefuzz
G[2860]={'FA 1418:53.80,43.32'}	-- Sigrun Ironhew
G[2888]={'1418:61.84,54.19'}
G[2909]={'947:0.00,0.00 1418:44.54,12.22>947 947:0.00,0.00 1418:65.03,43.51>947','Uldaman'}	-- Hammertoe Grez
G[2910]={'FA 1418:53.42,43.39'}	-- Prospector Ryedol
G[2911]={'FA 1437:10.76,60.40'}
G[2912]={'FA 1457:31.24,84.51'}	-- Chief Archaeologist Greywhisker
G[2913]={'FA 1439:37.44,41.84'}
G[2916]={'FA 1455:77.55,11.82'}	-- Historian Karnik
G[2917]={'FA 1439:35.76,83.71'}
G[2918]={'FA 1455:77.36,9.75'}	-- Advisor Belgrum
G[2920]={'1418:25.82,44.25'}	-- Lucien Tosselwrench
G[2921]={'1418:25.95,44.87'}	-- Lotwil Veriatus
G[2930]={'FA 1439:37.70,43.38'}
G[2934]={'FH 1458:53.72,54.44'}	-- Keeper Bel'dugur
G[2947]={'FH 1412:48.70,59.33'}	-- Harken Windtotem
G[2948]={'FH 1412:48.53,60.40'}	-- Mull Thunderhorn
G[2980]={'FH 1412:44.87,77.08'}	-- Grull Hawkwind
G[2981]={'FH 1412:44.18,76.05'}	-- Chief Hawkwind
G[2982]={'FH 1412:42.57,92.19'}	-- Seer Graytongue
G[2984]={'FH 1412:32.72,36.09','In cave'}	-- Seer Wiserunner
G[2985]={'FH 1412:47.36,62.01'}	-- Ruul Eagletalon
G[2987]={'FH 1456:37.69,59.55'}	-- Eyahn Eagletalon
G[2988]={'FH 1412:59.85,62.53 1412:57.47,61.25 1412:51.51,59.24','Patrols the road'}	-- Morin Cloudstalker
G[2991]={'FH 1412:50.03,81.15'}	-- Greatmother Hawkwind
G[2993]={'FH 1412:47.52,60.17'}	-- Baine Bloodhoof
G[2994]={'FH 1412:61.45,21.02'}	-- Ancestral Spirit
G[2995]={'FH 1456:47.00,49.83','At top of tower'}	-- Tal
G[3032]={'FH 1456:22.60,19.60'}
G[3033]={'FH 1456:76.46,27.23'}	-- Turak Runetotem
G[3034]={'FH 1456:77.13,27.00'}	-- Sheal Runetotem
G[3036]={'FH 1456:77.13,29.83'}	-- Kym Wildmane
G[3038]={'FH 1456:58.48,88.28'}	-- Kary Thunderhorn
G[3039]={'FH 1456:57.30,89.78'}	-- Holt Thunderhorn
G[3041]={'FH 1456:57.20,8740'}
G[3044]={'FH 1456:25.31,15.32'}	-- Miles Welsh
G[3049]={'FH 1456:25.18,20.94','Pools of Vision'}	-- Thurston Xane
G[3050]={'FH 1456:44.39,44.71'}	-- Veren Tallstrider
G[3052]={'FH 1412:46.76,60.23'}	-- Skorn Whitecloud
G[3054]={'FH 1412:47.76,57.53'}	-- Zarlman Two-Moons
G[3055]={'FH 1412:46.99,57.07'}	-- Maur Raincaller
G[3056]={'1412:45.87,39.71 1412:41.64,40.04 1412:36.38,39.25 1412:33.75,17.31 1412:35.34,17.33 1412:38.28,13.54 1412:42.35,12.87 1412:46.99,16.24','Walks in wide area'}	-- Ghost Howl
G[3057]={'FH 1456:60.30,51.69'}	-- Cairne Bloodhoof
G[3059]={'FH 1412:44.01,76.13'}	-- Harutt Thunderhorn
G[3060]={'FH 1412:45.08,75.94'}	-- Gart Mistrunner
G[3061]={'FH 1412:44.26,75.70'}	-- Lanka Farshot
G[3062]={'FH 1412:45.02,75.94'}	-- Meela Dawnstrider
G[3063]={'FH 1412:49.52,60.58'}	-- Krang Stonehoof
G[3064]={'FH 1412:48.48,59.65'}	-- Gennia Runetotem
G[3065]={'FH 1412:47.82,55.69'}	-- Yaw Sharpmane
G[3066]={'FH 1412:48.38,59.16'}	-- Narm Skychaser
G[3139]={'FH 1411:51.95,43.50'}	-- Gar'Thok
G[3140]={'FH 1411:54.43,74.36 1411:54.53,75.20 1411:54.07,76.32 1411:54.49,74.97 1411:54.24,73.27'}	-- Lar Prowltusk
G[3142]={'FH 1411:52.24,43.15'}	-- Orgnil Soulscar
G[3143]={'FH 1411:42.06,68.33'}	-- Gornek
G[3145]={'FH 1411:42.85,69.14'}	-- Zureetha Fargaze
G[3147]={'FH 1411:49.88,40.38'}	-- Furl Scornbrow
G[3153]={'FH 1411:42.89,69.43'}	-- Frang
G[3154]={'FH 1411:42.84,69.33'}-- Jen'shan
G[3155]={'FH 1411:41.28,68.01'}	-- Rwag
G[3156]={'FH 1411:40.65,68.52'}	-- Nartok
G[3157]={'FH 1411:42.39,69.00'}	-- Shikrik
G[3169]={'FH 1411:54.19,42.47'}	-- Tarshaw Jaggedscar
G[3170]={'FH 1411:51.98,43.69'}	-- Kaplak
G[3171]={'FH 1411:51.85,43.48'}	-- Thotar
G[3173]={'FH 1411:54.41,42.59'}	-- Swart
G[3188]={'FH 1411:55.95,74.72'}	-- Master Gadrin
G[3189]={'FH 1454:47.23,53.56'}	-- Kor'ghan
G[3190]={'FH 1411:41.54,18.61'}	-- Rhinag
G[3191]={'FH 1411:51.11,42.45'}	-- Cook Torka
G[3193]={'FH 1411:43.10,30.24'}	-- Misha Tor'kren
G[3194]={'FH 1411:55.95,73.93'}	-- Vel'rin Fang
G[3204]={'FH 1411:51.84,10.02 1411:52.62,8.78'}	-- Gazz'uz
G[3208]={'FH 1411:56.42,20.03'}	-- Margoz
G[3209]={'FH 1412:44.41,76.32','Walks in area'}	-- Brave Windfeather
G[3216]={'FH 1454:49.49,50.61'}	-- Neeru Fireblade
G[3230]={'FH 1454:32.24,35.80'}	-- Nazgrel
G[3233]={'FH 1412:59.86,25.62'}	-- Lorekeeper Raintotem
G[3247]={'1455:33.44,65.57'}
G[3253]={'1413:42.20,69.80 1413:45.50,69.90 1413:48.20,69.30','Very rare spawn'}	-- Silithid Harvester
G[3287]={'FH 1411:40.60,62.59'}	-- Hana'zua
G[3292]={'FH 1413:62.26,38.39'}	-- Brewmaster Drohn
G[3293]={'1411:46.37,22.94'}	-- Rezlak - quest giver both factions
G[3294]={'FH 1411:54.37,41.28'}	-- Ophek
G[3304]={'FH 1411:55.94,74.39'}	-- Master Vornal
G[3309]={'FH 1454:49.8,70.0'}
G[3310]={'FH 1454:45.13,63.89'}	-- Doras
G[3324]={'FH 1454:48.00,46.03'}	-- Grol'dar
G[3326]={'FH 1454:48.47,45.46'}	-- Zevrost
G[3328]={'FH 1454:43.96,54.57'}	-- Ormok
G[3336]={'FH 1411:50.84,43.59'}	-- Takrin Pathseeker
G[3337]={'FH 1413:62.26,19.38'}	-- Kargal Battlescar
G[3338]={'FH 1413:52.23,31.01'}	-- Sergra Darkthorn
G[3339]={'1413:62.28,39.03'}	-- Captain Thalo'thas Brightsun
G[3341]={'FH 1413:46.0,76.0 1413:46.15,78.5 1413:46.0,81.2'}	-- Gann Stonespire
G[3344]={'FH 1454:38.87,36.37'}	-- Kardris Dreamseeker
G[3352]={'FH 1454:66.04,18.52'}	-- Ormak Grimshot
G[3353]={'FH 1454:79.85,31.42'}	-- Grezz Ragefist
G[3354]={'FH 1454:80.39,32.38'}	-- Sorek
G[3387]={'FH 1413:44.86,59.13'}	-- Jorn Skyseer
G[3388]={'FH 1413:65.84,43.86'}	-- Mahren Skyseer
G[3389]={'FH 1413:45.34,28.41'}	-- Regthar Deathgate
G[3390]={'FH 1413:51.44,30.15'}	-- Apothecary Helbrim
G[3391]={'1413:62.68,36.24'}	-- Gazlowe
G[3399]={'FH 1454:57.39,53.96'}	-- Zamja
G[3401]={'FH 1454:43.06,53.74'}	-- Shenthul
G[3402]={'FH 1454:42.73,52.94'}	-- Zando'zan
G[3406]={'FH 1454:67.23,20.11'}	-- Xor'juul
G[3407]={'FH 1454:67.96,17.79'}	-- Sian'dur
G[3412]={'FH 1454:75.98,25.40'}	-- Nogg
G[3418]={'FH 1413:44.88,58.62'}	-- Kirge Sternhorn
G[3419]={'FH 1456:22.83,20.90','In cave'}	-- Apothecary Zamah
G[3421]={'FH 1413:48.95,85.30'}	-- Feegly the Exiled
G[3428]={'FH 1413:51.07,29.63'}	-- Korran
G[3429]={'FH 1413:51.50,30.87'}	-- Thork
G[3430]={'FH 1413:44.55,59.27'}	-- Mangletooth
G[3432]={'FH 1413:51.95,31.58'}	-- Mankrik
G[3433]={'FH 1413:45.10,57.69'}	-- Tatternack Steelforge
G[3439]={'1413:56.51,7.45'}	-- Wizzlecrank's Shredder
G[3441]={'FH 1456:61.54,80.90'}	-- Melor Stonehoof
G[3442]={'1413:62.98,37.22'}	-- Sputtervalve
G[3443]={'FH 1413:55.31,31.79'}	-- Grub
G[3446]={'1413:62.37,37.62'}	-- Mebok Mizzyrix
G[3448]={'FH 1413:52.26,31.93'}	-- Tonga Runetotem
G[3449]={'FH 1413:51.62,30.90','Top of tower'}	-- Darsok Swiftdagger
G[3453]={'1413:63.35,38.45'}	-- Wharfmaster Dizzywig
G[3464]={'FH 1413:51.93,30.32'}	-- Gazrog
G[3465]={'FH 1413:61.98,54.98'}	-- Gilthares Firebough
G[3472]={'1413:44.49,79.24 1413:43.23,80.65 1413:44.82,74.39 1413:47.48,79.61'}	-- Washte Pawne
G[3473]={'1413:44.52,62.39 1413:45.93,62.58 1413:48.90,62.84 1413:49.31,61.25'}	-- Owatanka
G[3474]={'1413:47.65,51.26 1413:48.18,53.26 1413:48.17,49.17 1413:49.89,53.00'}	-- Lakota'mani
G[3483]={'FH 1413:51.21,29.05'}	-- Jahan Hawkwing
G[3484]={'FH 1413:52.20,31.70'}	-- Kil'hala
G[3489]={'FH 1413:52.62,29.84'}	-- Zargh
G[3514]={'FA 1438:59.07,39.44'}	-- Tenaron Stormgrip
G[3515]={'FA 1438:56.14,61.71'}	-- Corithras Moonrage
G[3516]={'FA 1457:35.04,8.96','Top of building, walks in area'}	-- Arch Druid Fandral Staghelm
G[3517]={'FA 1457:38.20,21.67'}	-- Rellian Greenspyre
G[3519]={'FA 1438:38.32,34.36'}	-- Sentinel Arynia Cloudsbreak
G[3520]={'FA 1453:52.37,42.12 1453:48.20,48.78 1453:49.94,51.96 1453:53.00,55.41 1453:57.38,54.75 1453:60.58,60.36','Upstairs when home, walks a path'}	-- Ol' Emma
G[3521]={'FH 1413:62.34,20.07'}	-- Ak'Zeloth
G[3535]={'1438:44.13,30.28 1438:42.51,37.89'}	-- Blackmoss the Fetid
G[3567]={'FA 1438:55.57,56.95'}	-- Tallonkai Swiftroot
G[3568]={'FA 1438:31.53,31.61','May be on escort quest'}	-- Mist
G[3583]={'FA 1439:37.32,43.65'}
G[3584]={'FA 1439:38.62,87.39'}
G[3585]={'FA 1440:22.70,51.91'}
G[3593]={'FA 1438:59.63,38.45'}	-- Alyissia
G[3594]={'FA 1438:59.63,38.67'}	-- Frahun Shadewhisper
G[3595]={'FA 1438:59.18,40.45'}	-- Shanda
G[3596]={'FA 1438:58.65,40.45'}	-- Ayanna Everstride
G[3597]={'FA 1438:58.62,40.28'}	-- Mardant Strongoak
G[3598]={'FA 1438:56.22,59.20'}	-- Kyra Windblade
G[3599]={'FA 1438:56.38,60.14'}	-- Jannok Breezesong
G[3600]={'FA 1438:55.57,56.74'}	-- Laurna Morninglight
G[3601]={'FA 1438:56.67,59.49'}	-- Dazalar
G[3602]={'FA 1438:55.94,61.56'}	-- Kal
G[3615]={'FH 1413:51.51,30.34'}	-- Devrak
G[3616]={'FA 1439:43.57,76.36'}
G[3639]={'FA 1439:40.28,59.73'}
G[3644]={'FA 1439:35.74,43.70'}
G[3649]={'FA 1439:37.40,40.13'}	-- Thundris Windweaver
G[3650]={'FA 1439:44.22,36.32'}
G[3657]={'FA 1439:39.05,43.56','Upstairs'}	-- Sentinel Elissa Starbreeze
G[3661]={'FA 1439:54.97,24.89'}
G[3663]={'FA 1440:26.19,38.70'}	-- Delgren the Purifier
G[3665]={'1413:63.09,37.61'}	-- Crane Operator Bigglefuzz
G[3666]={'FA 1439:36.97,44.13','Upstairs'}
G[3691]={'FA 1440:36.61,49.61'}
G[3692]={'FA 1439:45.03,85.37'}
G[3693]={'FA 1439:39.37,43.48'}	-- Terenthis
G[3694]={'FA 1439:39.30,43.47'}
G[3701]={'FA 1439:38.84,43.42'}	-- Tharnariun Treetender
G[3702]={'FA 1439:37.66,40.65'}	-- Alanndarian Nightsong
G[3706]={'FH 1411:54.26,42.94'}	-- Tai'jin
G[3707]={'FH 1411:42.36,68.81'}	-- Ken'jai
G[3836]={'FA 1432:18.18,84.03'}	-- Mountaineer Pebblebitty
G[3838]={'FA 1438:58.40,94.02'}	-- Vesprystus
G[3845]={'FA 1440:34.68,48.87'}
G[3846]={'FA 1440:14.79,31.30'}	-- Talen 
G[3847]={'FA 1440:26.40,38.57'}
G[3848]={'FA 1440:85.30,44.71'}
G[3880]={'FA 1440:22.26,52.91'} -- Sentinel Melyria Frostshadow
G[3885]={'FA 1440:49.84,67.18'}
G[3891]={'FA 1440:20.30,42.25'}
G[3894]={'FA 1440:37.34,51.80'}
G[3897]={'FA 1440:50.87,75.11'}
G[3901]={'FA 1440:21.75,53.26'} -- Illiyana
G[3916]={'FA 1440:53.46,46.34'}
G[3920]={'FA 1440:78.30,44.89'}
G[3936]={'FA 1444:30.32,46.16'}
G[3945]={'1434:27.31,74.08'}
G[3979]={'FA 1455:74.95,12.50'}	-- Librarian Mae Paledust
G[3980]={'FA 1424:51.45,58.50'}
G[3994]={'FA 1442:37.10,8.13'}
G[3995]={'FH 1442:74.54,97.93'}	-- Witch Doctor Jin'Zil
G[3996]={'FA 1440:35.79,49.10'}
G[4046]={'FH 1456:69.85,30.90'}	-- Magatha Grimtotem
G[4047]={'FH 1454:38.91,38.43'}	-- Zor Lonetree
G[4048]={'FA 1444:89.60,46.59'}
G[4049]={'FH 1413:35.26,27.87'}	-- Seereth Stonebreak
G[4077]={'FA 1442:59.56,67.08'}
G[4078]={'FA 1453:43.09,80.38'}	-- Collin Mauren
G[4079]={'FA 1440:34.92,49.81'}
G[4080]={'FA 1442:59.86,66.87'}
G[4081]={'FA 1455:72.11,51.89'}	-- Lomac Gearstrip
G[4088]={'FA 1457:57.31,34.60'}	-- Elanaria
G[4090]={'FA 1457:38.33,80.95'}	-- Astarii Starseeker
G[4146]={'FA 1457:40.38,8.53'}	-- Jocaste
G[4155]={'FA 1457:39.41,42.62'}	-- Idriana
G[4163]={'FA 1457:36.99,21.92'}	-- Syurna
G[4197]={'FH 1442:73.20,95.00'}
G[4198]={'FH 1442:45.94,60.42'}	-- Braelyn Firehand
G[4200]={'FA 1439:36.77,44.28'}	-- Laird
G[4201]={'1442:58.99,62.59'}	-- Ziz Fizziks
G[4212]={'FA 1457:64.43,21.54','Upstairs'}	--Telonis
G[4214]={'FA 1457:34.51,25.95'}	-- Erion Shadewhisper
G[4215]={'FA 1457:37.91,20.79'}	-- Anishar
G[4217]={'FA 1457:35.37,8.42'}	-- Mathrengyl Bearwalker
G[4218]={'FA 1457:34.78,7.37'}	-- Denatharion
G[4219]={'FA 1457:33.51,8.32'}	-- Fylerian Nightwing
G[4241]={'FA 1457:70.68,45.39'}	-- Mydrannul
G[4256]={'FA 1455:51.50,26.30'}	-- Golnir Bouldertoe
G[4276]={'1442:71.8,60.0','In mine'}
G[4444]={'947:0.00,0.00 1421:44.82,67.83>947','Shadowfang Keep'}
G[4452]={'1441:77.83,77.24'}
G[4453]={'1441:78.08,77.09'}
G[4454]={'1441:78.01,77.11'}
G[4455]={'FA 1437:9.96,57.95'}
G[4456]={'FA 1445:66.45,45.14'}	-- Fiora Longears
G[4465]={'1425:68.00,63.20 1425:67.80,67.60'}	-- Vilebranch Warrior
G[4483]={'FH 1441:67.6,64.0'}
G[4484]={'FA 1440:26.21,38.88'}	-- Feero Ironhand
G[4485]={'FH 1454:75.22,34.25'}	-- Belgrom Rockmaul
G[4486]={'FH 1458:63.85,49.45'}	-- Genavie Callow
G[4496]={'1441:79.85,76.72'}
G[4498]={'FH 1443:52.2,53.6'}
G[4503]={'1445:35.11,38.26'}
G[4508]={'947:0.00,0.00 1413:42.63,90.14>947','Razorfen Kraul'}	-- Willix the Importer
G[4551]={'FH 1458:63.26,48.55'}
G[4556]={'FH 1458:61.52,41.83'}
G[4563]={'FH 1458:86.00,15.60'}
G[4568]={'FH 1458:85.14,10.01'}	-- Anastasia Hartwell
G[4576]={'FH 1458:70.77,30.69'}	-- Josef Gregorian
G[4582]={'FH 1458:83.88,72.06'}	-- Carolyn Ward
G[4583]={'FH 1458:85.20,71.57'}	-- Miles Dexter
G[4593]={'FH 1458:46.90,15.20'}
G[4595]={'FH 1458:47.40,17.30'}
G[4606]={'FH 1458:49.00,18.35'}	-- Aelthalyste
G[4618]={'1418:42.28,52.64'}
G[4630]={'1441:80.10,75.85'}
G[4631]={'1434:26.4,73.6'}
G[4663]={'1443:56.6,30.0 1443:53.0,32.4'}
G[4664]={'1443:56.0,30.6 1443:57.6,26.2'}
G[4665]={'1443:57.2,27.8 1443:56.6,30.0'}
G[4666]={'1443:55.6,28.0 1443:55.2,30.2'}
G[4667]={'1443:52.8,28.8 1443:55.6,26.2'}
G[4668]={'1443:51.4,27.6 1443:53.6,82.6 1443:56.8,75.8'}
G[4705]={'1443:79.8,77.6 1443:81.2,82.0'}
G[4706]={'1441:80.26,76.13'}
G[4708]={'1446:50.96,27.24'}	-- Shreev
G[4709]={'1441:79.77,76.94'}
G[4721]={'FH 1456:54.97,51.36'}	-- Zangen Stonehoof
G[4783]={'FA 1457:56.15,24.39'}	-- Dawnwatcher Selgorm
G[4784]={'FA 1457:55.24,23.98'}	-- Argent Guard Manados
G[4786]={'FA 1457:55.37,25.03'}	-- Dawnwatcher Shaedlass
G[4787]={'947:0.00,0.00 1440:14.09,14.87>947','Blackfathom Deeps'}	-- Argent Guard Thaelrid
G[4792]={'1445:55.44,26.32'}
G[4794]={'FA 1445:66.35,45.44'}
G[4802]={'947:0.00,0.00 1440:14.09,14.87>947','Blackfathom Deeps'}	-- Blackfathom Tide Priestess
G[4880]={'1445:46.93,17.53'}
G[4921]={'FA 1445:66.15,46.08'}
G[4926]={'FH 1445:36.42,31.88'}	-- Krog
G[4941]={'FA 1445:64.73,50.35'}
G[4943]={'FH 1456:54.00,80.80'}	-- Mosarn
G[4944]={'FA 1445:68.19,48.54'}
G[4947]={'FA 1445:65.05,47.07'}
G[4948]={'FA 1445:68.03,48.21'}
G[4949]={'FH 1454:31.75,37.80'}	-- Thrall
G[4959]={'FA 1453:73.16,78.42'}	-- Jorgen
G[4960]={'FA 1453:78.27,25.58'}	-- Bishop DeLavey
G[4961]={'FA 1453:70.53,44.86'}	-- Dashel Stonefist
G[4962]={'FA 1437:10.55,60.26'}
G[4963]={'FA 1437:10.60,60.77'}	-- Mikhail
G[4964]={'FA 1445:67.95,48.60'}
G[4966]={'FA 1445:45.20,24.55'}
G[4967]={'FA 1445:59.70,41.17'}
G[4968]={'FA 1445:45.18,24.26', 'Top of tower'}	-- Lady Jaina Proudmoore
G[4982]={'FA 1453:41.42,31.02 1453:39.05,26.07','Walks in Cathedral'}	-- Thomas
G[4984]={'FA 1453:21.41,55.81'}	-- Argos Nightwhisper
G[5081]={'FA 1453:40.64,91.87'}	-- Connor Rivers
G[5082]={'FA 1437:10.82,60.40'}
G[5083]={'FA 1445:67.90,48.20'}
G[5089]={'1445:36.12,54.27'}
G[5111]={'FA 1455:18.16,51.51'}	-- Innkeeper Firebrew
G[5113]={'FA 1455:70.30,90.70'}
G[5116]={'FA 1455:70.88,83.62'}	-- Olmin Burningbeard
G[5117]={'FA 1455:69.87,82.93'}	-- Regnus Thundergranite
G[5144]={'FA 1455:27.23,8.29'}	-- Bink
G[5149]={'FA 1455:23.12,6.15'}	-- Brandur Ironhammer
G[5150]={'FA 1455:55.10,58.26','Upstairs'}	-- Nissa Firestone
G[5161]={'FA 1455:48.06,6.91','Upstairs'}	-- Grimnur Stonebrand
G[5165]={'FA 1455:51.97,14.85'}	-- Hulfdan Blackbeard
G[5166]={'FA 1455:51.97,14.85'}	-- Ormyr Flinteye
G[5172]={'FA 1455:50.33,5.66'}	-- Briarthorn
G[5174]={'FA 1455:68.44,43.55'}	-- Springspindle Fizzlegear
G[5204]={'FH 1458:50.14,67.98'}	-- Apothecary Zinge
G[5353]={'1435:13.66,71.72'}	-- Itharius
G[5384]={'FA 1453:64.35,20.62'}	-- Brohann Caskbelly
G[5385]={'FA 1419:67.60,19.20'}
G[5386]={'FA 1453:41.01,63.81','Upstairs'}	-- Acolyte Dellis
G[5387]={'FA 1455:69.91,18.57'}	-- High Explorer Magellas
G[5391]={'1435:65.48,18.15'}	-- Galen Goodward
G[5393]={'FA 1419:66.49,21.37'}
G[5394]={'FH 1435:47.70,55.20'}
G[5395]={'FH 1443:56.2,59.6'}
G[5396]={'FA 1443:66.63,11.05'}
G[5397]={'1443:36.33,79.23'}
G[5398]={'1443:74.8,68.0'}
G[5411]={'1446:51.46,28.81'}	-- Krinkle Goodsteel
G[5412]={'FH 1443:56.2,59.6'}
G[5413]={'FA 1453:58.09,16.56'}	-- Furen Longbeard
G[5459]={'1446:39.00,29.20 1446:38.00,41.00'}	-- Centipaar Tunneler
G[5464]={'FA 1431:75.75,46.17'}
G[5469]={'1446:37.60,81.40'}	-- Dune Smasher
G[5475]={'1446:40.40,54.60 1446:46.80,67.00 1446:41.80,72.40'}	-- Dunemaul Warlock
G[5476]={'FA 1435:26.66,59.87'}
G[5477]={'1435:58.69,40.94 1435:54.13,33.78 1435:51.42,38.66 1435:44.11,35.57 1435:35.91,40.77 1435:32.75,38.26 1435:31.23,40.60 1435:33.70,48.17'}	-- Noboru the Cudgel
G[5479]={'FA 1453:78.69,45.78'}	-- Wu Shen
G[5480]={'FA 1453:78.50,45.70'}	-- Ilsa Corbin
G[5489]={'FA 1453:38.55,26.86'}	-- Brother Joshua
G[5495]={'FA 1453:26.20,77.25'}  --  Ursula Deline
G[5497]={'FA 1453:38.61,79.30','Top of tower'}	-- Jennea Cannon
G[5504]={'FA 1453:20.90,55.51'}	-- Sheldras Moontree
G[5505]={'FA 1453:21.29,51.55'}	-- Theridran
G[5515]={'FA 1453:61.62,15.28'}	-- Einris Brightspear
G[5520]={'FA 1453:25.66,77.68'}	-- Spackle Thornberry
G[5543]={'FH 1456:28.80,26.60 1456:27.20,24.92', 'Pacing in a cave'}	-- Clarice Foster
G[5566]={'FA 1453:44.74,77.11'}	-- Tannysa
G[5591]={'FH 1435:44.69,57.21'}	-- Dar
G[5592]={'FH 1435:81.32,80.97'}	-- Tok'Kar
G[5593]={'FH 1435:83.76,80.41'}	-- Katar
G[5594]={'1446:50.89,26.97'}	-- Alchemist Pestlezugg
G[5598]={'1435:33.80,75.20'}
G[5634]={'1425:26.92,48.46'}
G[5635]={'FA 1425:11.85,46.71'}
G[5636]={'FA 1425:9.80,44.50'}
G[5637]={'FA 1455:68.66,19.38','Walks in area'}	-- Roetten Stonehammer
G[5638]={'FA 1443:66.21,9.70'}
G[5639]={'FH 1454:44.8,51.8 1454:49.4,51.4 1454:51.6,46.6 1454:52.2,44.4'}	-- Craven Drok
G[5640]={'FH 1454:22.27,53.86'}	-- Keldran
G[5641]={'FH 1443:52.6,54.2'}
G[5642]={'FA 1443:66.49,11.68'}
G[5644]={'FA 1443:54.90,26.19'}
G[5647]={'1446:39.60,21.40'}	-- Sandfury Firecaller
G[5667]={'FH 1420:30.98,66.41'}	-- Venya Marthand
G[5675]={'FH 1458:85.04,26.00'}	-- Carendin Halgar
G[5688]={'FH 1420:61.71,52.05'}	-- Innkeeper Renee
G[5693]={'FH 1458:85.00,16.60'}
G[5694]={'FA 1453:37.53,81.65','Top of tower'}	-- High Sorcerer Andromath
G[5724]={'FH 1420:61.62,52.68'}	-- Ageron Kargal
G[5752]={'FA 1443:66.78,10.81'}
G[5753]={'FH 1458:85.80,15.80'}
G[5765]={'FH 1411:42.59,69.00'}	-- Ruzan
G[5767]={'1414:51.91,55.42 1413:45.78,36.26>1414','In cave above Wailing Caverns entrance'}	-- Nalpak
G[5768]={'1414:51.92,55.44 1413:45.78,36.26>1414','In cave above Wailing Caverns entrance'}	-- Ebru
G[5769]={'FH 1456:78.63,28.54'}	-- Arch Druid Hamuul Runetotem
G[5770]={'FH 1456:75.65,31.59'}	-- Nara Wildmane
G[5797]={'1413:47.4,42.6 1413:50.4,43.8 1413:49.0,49.8 1413:49.8,55.6 1413:46.4,62.8 1413:48.6,62.8 1413:47.2,65.6 1413:46.6,71.6 1413:48.6,79.6'}	-- Aean Swiftriver
G[5810]={'FH 1413:61.38,21.11'}	-- Uzzek
G[5815]={'FH 1454:47.52,46.71'}	-- Kurgul
G[5833]={'1427:69.46,71.74 1427:71.25,73.12 1427:69.71,76.50'}	-- Margol the Rager
G[5840]={'1427:38.20,50.80 1427:40.80,49.80 1427:42.80,51.60'}	-- Dark Iron Steamsmith
G[5844]={'1427:44.00,26.00 1427:44.60,36.00 1427:45.60,39.60 1427:38.60,45.20 1427:42.80,51.60 1427:47.80,52.20'}	-- Dark Iron Slaver
G[5846]={'1427:44.00,26.00 1427:46.00,28.20 1427:39.80,32.60 1427:45.40,38.40 1427:37.00,40.80 1427:40.60,51.40 1427:44.60,51.80'}	-- Dark Iron Taskmaster
G[5875]={'FH 1454:48.25,45.27'}	-- Gan'rul Bloodeye
G[5878]={'FH 1413:57.23,30.34','Up mountain'}	-- Thun'grim Firegaze
G[5880]={'FH 1411:56.31,75.11'}	-- Un'Thuwa
G[5884]={'FH 1411:42.51,69.04'}	-- Mai'ah
G[5885]={'FH 1454:38.45,86.12'}	-- Deino
G[5887]={'FH 1411:42.40,69.18'}	-- Canaga Earthcaller
G[5888]={'FH 1412:44.73,76.18'}	-- Seer Ravenfeather
G[5891]={'FH 1411:44.00,76.18'}	-- Minor Manifestation of Earth
G[5892]={'FH 1454:37.96,37.70'}	-- Searn Firewarder
G[5895]={'FH 1421:38.60,44.60'}
G[5899]={'FH 1413:43.42,77.41'}	-- Brine
G[5900]={'FH 1411:38.54,58.91'}	-- Telf Joolam
G[5901]={'1413:65.83,43.77'}	-- Islen Waterseer
G[5905]={'FH 1441:53.60,42.80'}
G[5906]={'FH 1456:25.60,21.60'}
G[5907]={'FH 1413:55.87,19.95'}	-- Kranal Fiss
G[5908]={'FH 1413:43.31,47.89'}	-- Grunt Dogran
G[5909]={'FH 1454:47.04,46.46'}	-- Cazul
G[5910]={'FH 1454:37.02,59.45'}	-- Zankaja
G[5911]={'FH 1413:44.62,59.27'}	-- Grunt Logmar
G[5955]={'1446:29.53,60.44 1446:32.36,74.21'}	-- Tooga
G[5994]={'FH 1454:35.68,86.97'}	-- Zayus
G[6015]={'1446:66.6,25.6'}
G[6018]={'FH 1454:35.60,87.82'}	-- Ur'kyo
G[6019]={'1443:47.86,61.75'}
G[6030]={'FA 1432:23.63,74.36'}
G[6031]={'FA 1455:48.65,42.51'}	-- Tormus Deepforge
G[6034]={'FA 1457:64.39,22.23'}	--Lotherias
G[6089]={'FA 1453:74.28,37.27'}	-- Harry Burlguard
G[6090]={'FA 1453:73.79,36.32'}	-- Bartleby
G[6109]={'1447:59.04,82.03','Walks widely around area'}	-- Azuregos
G[6114]={'FA 1455:70.77,90.27'}	-- Muren Stormpike
G[6120]={'FA 1455:47.63,9.24'}	-- Lago Blackwrench
G[6121]={'FA 1429:44.48,66.26'}	-- Remen Marcot
G[6122]={'FA 1453:25.24,78.59'}	-- Gakin the Darkbinder
G[6134]={'1447:77.20,42.82'}
G[6142]={'FA 1457:59.51,45.37'}	-- Mathiel
G[6166]={'FA 1433:26.59,44.73'}	-- Yorus Barleybrew
G[6169]={'FA 1455:67.93,46.11'}	-- Klockmort Spannerspan
G[6171]={'FA 1453:39.82,29.79'}	-- Duthorian Rall
G[6172]={'FA 1429:72.60,51.43'}	-- Henze Faulk
G[6173]={'FA 1453:38.58,26.57'}	-- Gazin Tenorm
G[6174]={'FA 1453:57.08,61.76'}	-- Stephanie Turner
G[6175]={'FA 1455:21.82,51.93 1455:23.35,61.97 1455:32.42,78.40 1455:42.82,84.07'}	-- John Turner
G[6176]={'1416:80.40,66.80'}	-- Bath'rah the Windwatcher
G[6177]={'FA 1426:78.32,58.08'}	-- Narm Faulk
G[6178]={'FA 1455:23.53,8.31'} 	-- Muiredon Battleforge
G[6179]={'FA 1455:27.64,12.20'}	-- Tiza Battleforge
G[6181]={'FA 1426:52.49,36.92'}	-- Jordan Stilwell
G[6182]={'FA 1436:41.53,88.69'}	-- Daphne Stilwell
G[6236]={'1413:68.62,49.16'}	-- Klannoc Macleod 
G[6241]={'FA 1432:35.95,44.90'}	-- Bailor Stonehand
G[6244]={'FA 1413:49.31,57.10'}	-- Takar the Seer
G[6247]={'1413:49.31,57.21'}	-- Doan Karhan
G[6251]={'1413:62.63,35.50'}	-- Strahad Farsan
G[6252]={'1413:62.56,35.23'}	-- Acolyte Magaz
G[6254]={'1413:62.64,35.31'}	-- Acolyte Wytula
G[6266]={'1413:62.51,35.45'}	-- Menara Voidrender
G[6286]={'FA 1438:57.12,61.30'}	-- Zarrin
G[6293]={'FH 1458:76.60,36.80'}
G[6294]={'FA 1455:74.18,9.39'}	-- Krom Stoutarm
G[6301]={'FA 1439:38.11,41.17'}
G[6382]={'FA 1455:52.80,6.00'}
G[6389]={'FH 1421:43.43,41.67'}	-- Deathguard Podrig
G[6394]={'FH 1413:44.68,59.42'}	-- Ruga Ragetotem
G[6408]={'FH 1411:56.32,74.34'}	-- Ula'elek
G[6410]={'FH 1456:39.60,55.40'}
G[6411]={'FH 1458:62.80,40.00'}
G[6446]={'FH 1454:42.71,53.56'}	-- Therzok
G[6467]={'FH 1458:83.50,69.09'}	-- Mennet Carkad
G[6522]={'FH 1458:54.83,76.31'}	-- Andron Gant
G[6546]={'1445:46.01,57.12'}
G[6548]={'1441:78.2,75.8'}
G[6568]={'1446:51.01,27.36'}	-- Vizzclick
G[6569]={'FA 1455:69.16,50.54'}	-- Gnoarn
G[6577]={'FA 1432:63.56,47.92'}
G[6579]={'FA 1453:55.51,12.53'}	-- Shoni the Shilent
G[6667]={'FA 1439:56.67,13.51'}
G[6707]={'1416:84.45,80.30'}	-- Fahrad
G[6735]={'FA 1457:67.41,15.65'}	-- Innkeeper Saelienne
G[6736]={'FA 1438:55.62,59.79'}	-- Innkeeper Keldamyr
G[6740]={'FA 1453:52.62,65.70'}	-- Innkeeper Allison
G[6741]={'FH 1458:67.74,37.88'}	-- Innkeeper Norman
G[6746]={'FH 1456:45.81,64.70'}	-- Innkeeper Pala
G[6747]={'FH 1412:46.62,61.09'}	-- Innkeeper Kauth
G[6766]={'1416:84.59,78.71 1416:84.53,79.38 1416:85.58,79.11 1416:85.25,79.58 1416:81.94,77.98 1416:81.47,76.88 1424:77.77,20.00 1424:77.28,20.03'}	-- Ravenholdt Guard
G[6768]={'1416:86,79'}
G[6774]={'FA 1429:45.57,47.75'}	-- Falkhaan Isenstrider
G[6775]={'FH 1412:38.53,81.56'}	-- Antur Fallow
G[6780]={'FA 1438:61.16,47.64'}	-- Porthannius
G[6782]={'FA 1426:33.85,72.24'}	-- Hands Springsprocket
G[6784]={'FH 1420:38.25,56.76'}	-- Calvin Montague
G[6786]={'FH 1411:52.06,68.30'}	-- Ukor
G[6806]={'FA 1426:47.22,52.19'}	-- Tannok Frosthammer
G[6826]={'FA 1455:36.35,3.63'}	-- Talvash del Kissel
G[6846]={'1429:48.20,87.60'}	-- Defias Dockmaster
G[6868]={'FH 1418:2.43,46.05','Upstairs'}	-- Jarkal Mossmeld
G[6886]={'FA 1426:25.17,44.45'}	-- Onin MacHammar
G[6906]={'947:0.00,0.00 1418:44.54,12.22>947 947:0.00,0.00 1418:65.03,43.51>947','Uldaman'}	-- Baelog
G[6912]={'947:0.00,0.00 1418:44.54,12.22>947 947:0.00,0.00 1418:65.03,43.51>947','Uldaman'}	-- Remains of a Paladin
G[6927]={'1429:47.60,85.40'}	-- Defias Dockworker
G[6928]={'FH 1411:51.52,41.65'}	-- Innkeeper Grosk
G[6929]={'FH 1454:54.10,68.39'}	-- Innkeeper Gryshka
G[6946]={'FA 1453:75.78,60.36'}	-- Renzik "The Shiv"
G[6966]={'FA 1433:28.07,52.03'}	-- Lucius
G[6986]={'FH 1454:59.48,36.58'}	-- Dran Droffers
G[6987]={'FH 1454:59.65,36.94'}	-- Malton Droffers
G[7007]={'FH 1421:37.40,44.00'}
G[7010]={'FH 1454:56.27,46.67'}	-- Zilzibin Drumlore
G[7024]={'FA 1436:68.40,70.00'}
G[7114]={'1448:37.80,45.40 1448:39.80,49.20 1448:37.60,54.00','In cave'}	-- Jaedenar Enforcer
G[7118]={'1448:37.80,45.40 1448:39.80,49.20 1448:37.60,54.00','In cave'}	-- Jaedenar Darkweaver
G[7120]={'1448:37.80,45.40 1448:39.80,49.20 1448:37.60,54.00','In cave'}	-- Jaedenar Warlock
G[7156]={'1448:62.60,7.60 1448:63.60,11.60'}	-- Deadwood Den Watcher
G[7157]={'1448:62.60,7.60 1448:63.60,11.60'}	-- Deadwood Avenger
G[7158]={'1448:62.60,7.60 1448:63.60,11.60'}	-- Deadwood Shaman
G[7161]={'1413:63.07,36.32'}	-- Wrenix the Wretched
G[7207]={'FA 1453:78.03,58.75','Basement'}	-- Doc Mixilpixil
G[7233]={'1413:55.44,5.56','Walks near'}	-- Taskmaster Fizzule
G[7269]={'947:0.00,0.00 1446:38.72,20.00>947',"Inside Zul'Farrak"}	-- Scarab
G[7292]={'FA 1455:33.49,60.23'}	-- Dinita Stonemantle
G[7311]={'FH 1454:39.16,86.27'}	-- Uthel'nay
G[7312]={'FA 1455:27.17,8.58'}	-- Dink
G[7313]={'FA 1457:36.64,85.94','Upstairs'}	-- Priestess A'moora
G[7315]={'FA 1457:58.94,35.36'}	-- Darnath Bladesinger
G[7316]={'FA 1457:28.97,45.81'}	-- Sister Aquinne
G[7317]={'FA 1438:44.95,61.60'}	-- Oben Rageclaw
G[7363]={'1419:51.98,35.60'}
G[7406]={'1434:28.36,76.36'}	-- Oglethorpe Obnoticus
G[7407]={'1446:52.46,28.52'}	-- Chief Engineer Bilgewhizzle
G[7408]={'1446:52.49,28.44'}	-- Spigot Operator Luglunket
G[7438]={'1452:65.6,37.6 1452:69.6,38.2'}
G[7439]={'1452:68.2,37.0 1452:69.6,38.2'}
G[7440]={'1452:66.6,35.8 1452:67.0,39.8 1452:41.6,42.8 1452:33.0,36.8'}
G[7441]={'1452:32.4,37.6 1452:40.6,43.6'}
G[7442]={'1452:39.0,42.8 1452:42.6,43.2 1452:30.0,35.8 1452:34.6,37.2'}
G[7452]={'1452:65.6,19.6 1452:66.2,61.6 1452:59.6,60.0'}
G[7453]={'1452:66.6,21.6 1452:65.4,52.8 1452:58.2,59.6'}
G[7454]={'1452:65.6,24.2 1452:66.2,61.6 1452:59.6,59.8'}
G[7505]={'1419:50.65,14.23'}
G[7506]={'1419:50.73,14.26'}
G[7564]={'1446:51.81,28.66'}	-- Marin Noggenfogger
G[7572]={'1435:34.28,66.15'}	-- Fallen Hero of the Horde
G[7583]={'1446:51.06,26.87'}	-- Sprinkle
G[7605]={'947:0.00,0.00 1446:38.72,20.00>947',"Inside Zul'Farrak"}	-- Raven
G[7606]={'947:0.00,0.00 1446:38.72,20.00>947',"Inside Zul'Farrak"}	-- Oro Eyegouge
G[7608]={'947:0.00,0.00 1446:38.72,20.00>947',"Inside Zul'Farrak"}	-- Murta Grimgut
G[7623]={'FH 1435:47.79,54.93'}	-- Dispatch Commander Ruag
G[7643]={'FH 1435:44.98,57.38'}	-- Bengor
G[7683]={'FH 1458:58.61,54.67'}	-- Alessandro Luca
G[7724]={'1446:50.21,27.48'}	-- Senior Surveyor Fizzledowser
G[7729]={'1419:69.39,31.01'}
G[7740]={'FA 1457:41.84,85.63','Upper level'}	-- Gracina Spiritmight
G[7750]={'1435:33.34,65.97'}	-- Corporal Thund Splithoof
G[7763]={'1446:52.36,26.90'}	-- Curgle Cranklehop
G[7764]={'FA 1444:31.84,45.46'}
G[7765]={'FA 1444:42.35,21.95'}
G[7766]={'FA 1453:69.20,14.41'}	-- Tyrion
G[7771]={'1446:52.71,45.93'}	-- Marvon Rivetseeker
G[7773]={'1444:45.81,16.49'}
G[7774]={'FA 1444:38.23,10.28'}
G[7775]={'1444:45.13,25.53'}
G[7776]={'FH 1444:76.0,43.8'}
G[7777]={'FH 1444:74.2,44.6'}
G[7780]={'1425:30.74,46.97'}	-- Rin'ji
G[7783]={'1447:60.80,66.39'}
G[7784]={'1446:60.19,64.38'}	-- Homing Robot OOX-17/TN
G[7797]={'947:0.00,0.00 1446:38.72,20.00>947',"Inside Zul'Farrak"}	-- Ruuzlu
G[7801]={'1425:26.71,48.60'}
G[7802]={'1434:50.60,20.55'}
G[7804]={'1446:51.41,28.76'}	-- Trenton Lighthammer
G[7806]={'1425:49.32,37.62'}
G[7807]={'1444:53.38,55.69'}
G[7825]={'FH 1458:73.07,32.86'}	-- Oran Snakewrithe
G[7826]={'FA 1419:67.49,19.22'}
G[7852]={'FA 1444:30.62,42.66'}
G[7855]={'1446:71.6,43.4 1446:72.7,45.8 1446:73.6,48.2'}	-- Southsea Pirate
G[7856]={'1446:71.6,43.4 1446:72.7,45.8 1446:73.6,48.2'}	-- Southsea Freebooter
G[7857]={'1446:71.6,43.4 1446:72.7,45.8 1446:73.6,48.2'}	-- Southsea Dock Worker
G[7858]={'1446:71.6,43.4 1446:72.7,45.8 1446:73.6,48.2'}	-- Southsea Swashbuckler
G[7866]={'FA 1447:37.53,65.43'}
G[7876]={'1446:51.57,26.76'}	-- Tran'rek
G[7877]={'FA 1444:30.38,46.12'}
G[7878]={'FA 1444:30.12,45.12'}
G[7879]={'FA 1444:32.47,43.80'}
G[7880]={'FA 1444:31.87,45.19'}
G[7881]={'1446:67.11,23.98'}	-- Stoley
G[7882]={'1446:67.06,23.89'}	-- Security Chief Bilgewhizzle
G[7884]={'FA 1425:14.77,44.57'}
G[7900]={'FA 1444:31.86,45.61'}
G[7907]={'FA 1438:55.41,92.24','Upstairs'}	-- Daryn Lightwind
G[7916]={'FA 1438:55.49,92.04'}	-- Erelas Ambersky
G[7917]={'FA 1453:40.56,30.94'}	-- Brother Sarno
G[7937]={'FA 1455:68.76,48.99'}	-- High Tinker Mekkatorque
G[7944]={'FA 1455:69.57,50.33'}	-- Tinkmaster Overspark
G[7950]={'FA 1455:69.82,48.08'}	-- Master Mechanic Castpipe
G[7956]={'FA 1444:65.93,45.65'}
G[7957]={'FA 1444:65.92,45.62'}
G[7999]={'FA 1457:39.09,81.59'}	-- Tyrande Whisperwind
G[8022]={'FA 1419:66.95,19.50'}
G[8026]={'FA 1457:61.78,39.20'}	-- Thyn'tel Bladeweaver
G[8115]={'FH 1444:74.4,43.4'}
G[8125]={'1446:52.63,28.11'}	-- Dirge Quikcleave
G[8126]={'1446:52.4,27.2'}
G[8142]={'FH 1444:76.00,42.20'}	-- Jannos Lighthoof
G[8216]={'1425:47.60,66.60 1425:50.80,62.60 1425:51.20,66.60'}	-- Retherokk the Berserker
G[8256]={'FA 1455:77.05,26.96 1455:71.82,16.10 1455:64.30,3.76', 'Walks between points'}	-- Curator Thorius
G[8284]={'FA 1427:63.93,61.00'}	-- Dorius Stonetender
G[8359]={'FH 1456:45.76,55.82'}	-- Ahanu
G[8379]={'1447:28.00,50.00'}	-- Archmage Xylem
G[8380]={'1447:53.0,87.8'}
G[8385]={'FH 1421:42.91,41.99'}	-- Mura Runetotem
G[8390]={'FH 1458:48.69,71.42'}	-- Chemist Cuely
G[8393]={'FH 1458:49.05,70.78'}	-- Thersa Windsong
G[8395]={'1447:28.00,50.00'}	-- Sanath Lim-yo
G[8399]={'1447:26.48,46.22'}
G[8403]={'FH 1458:67.58,44.16'}	-- Jeremiah Payson
G[8405]={'1447:42.20,42.60'}	-- Ogtinc
G[8416]={'FA 1426:28.51,67.72'}	-- Felix Whindlebolt
G[8417]={'1427:41.13,25.58'}	-- Dying Archaeologist
G[8420]={'1447:53.40,21.80'}
G[8436]={'FA 1427:29.49,26.51'}	-- Zamael Lunthistle
G[8439]={'1427:40.99,74.96'}	-- Nilith Lokrav
G[8479]={'1427:39.05,38.99'}	-- Kalaran Windblade
G[8496]={'1413:62.45,38.74'}	-- Liv Rizzlefix
G[8504]={'1427:42.00,35.40 1427:34.20,54.00 1427:36.60,60.00 1427:43.40,62.00 1427:49.40,55.80'}	-- Dark Iron Sentry
G[8507]={'1455:30.98,4.84'}	-- Tymor
G[8509]={'1427:39.17,39.00'}	-- Squire Maltrake
G[8516]={'947:0.00,0.00 1413:49.26,98.08>947','Razorfen Downs'}	-- Belnistrasz
G[8517]={'FA 1455:70.86,94.59'}	-- Xiggs Fuselighter
G[8566]={'1427:33.80,51.20 1427:32.60,55.00 1427:37.20,60.40 1427:44.60,62.60 1427:52.40,57.80'}	-- Dark Iron Lookout
G[8576]={'FH 1447:22.2,51.4'}
G[8579]={'1446:66.99,22.35'}	-- Yeh'kinya
G[8582]={'FH 1413:48.12,5.42','Up tower'}	-- Kadrak
G[8583]={'FA 1438:60.90,41.96'}	--Dirania Silvershine
G[8584]={'FA 1438:54.59,32.99'}	-- Iverron
G[8587]={'FH 1447:22.6,51.4'}
G[8659]={'FH 1454:55.54,34.08'}	-- Jes'rimon
G[8737]={'1449:44.67,8.26'}
G[8879]={'FA 1455:38.38,55.32'}	-- Royal Historian Archesonus
G[8929]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Depths'}	-- Princess Moira Bronzebeard
G[8962]={'1433:29.24,53.63'}	-- Hilary - Friendly to Horde also.
G[8965]={'1433:29.31,53.64'}	-- Shawn - Friendly to Horde also.
G[8997]={'FA 1439:38.33,43.04'}	-- Gershala Nightwhisper
G[9020]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Depths'}	-- Commander Gor'shak
G[9021]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Depths'}	-- Kharan Mighthammer
G[9046]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Mountain'}	-- Scarshield Quartermaster
G[9047]={'FA 1457:31.49,8.23'}	-- Jenal
G[9076]={'FH 1456:77.45,21.97'}	-- Ghede
G[9077]={'FH 1418:3.70,48.72 1418:2.99,47.67 1418:5.81,47.53','Walks around and goes up tower'}	-- Warlord Goretooth
G[9078]={'FH 1418:2.90,47.75'}	-- Shadowmage Vivian Lagrave
G[9079]={'FH 1418:3.02,47.81'}	-- Hierophant Theodora Mulvadania
G[9080]={'FH 1418:5.87,47.63'}	-- Lexlort
G[9081]={'FH 1418:5.96,47.75'}	-- Galamav the Marksman
G[9087]={'FH 1456:71.08,34.17'}	-- Bashana Runetotem
G[9116]={'1448:51.32,81.57'}
G[9117]={'1449:41.91,2.69'}	-- J.D. Collie
G[9119]={'FA 1449:42.96,9.52'}
G[9177]={'FA 1428:84.48,68.63'}
G[9238]={'FA 1441:78.37,74.82'}
G[9270]={'1449:43.94,7.14'}	-- Williden Marshal
G[9271]={'1449:43.89,7.24'}	-- Hol'anyee Marshal
G[9272]={'1449:43.50,7.42'}	-- Spark Nilminer
G[9274]={'1449:43.64,7.17'}	-- Dadanga
G[9296]={'FA 1429:50.69,39.35'}	-- Milly Osworth
G[9298]={'1452:31.25,45.18'}
G[9299]={'1446:54.01,23.28','Only visible when dead'}	-- Gaeriyan
G[9316]={'1413:49.05,11.17'}	-- Wenikee Boltbucket
G[9317]={'FH 1454:76.50,24.43'}	-- Rilli Greasygob
G[9459]={'1428:94.97,31.65'}
G[9465]={'FA 1444:62.00,24.40'}	-- Golhine the Hooded
G[9503]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Depths'}	-- Private Rocknot
G[9516]={'1448:36.00,44.60'}
G[9520]={'1428:40.8,32.8'}
G[9528]={'1448:54.18,86.89'}
G[9529]={'1448:46.8,83.0'}
G[9536]={'1428:65.15,23.90'}	-- Maxwort Uberglint
G[9540]={'FA 1419:63.71,20.57'}
G[9544]={'1428:66.06,21.96'}	-- Yuka Screwspigot
G[9550]={'HV FH 1454:50.86,65.28'}	-- Furmund
G[9560]={'FA 1428:84.67,69.03'}
G[9561]={'FA 1428:85.38,69.99'}
G[9562]={'FA 1428:85.78,68.79'}
G[9563]={'1428:65.01,23.75'}	-- Ragged John
G[9565]={'FA 1428:84.80,69.05'}
G[9598]={'FA 1448:49.51,29.64'}
G[9616]={'FA 1455:75.78,23.40'}	-- Laris Geardawdle
G[9618]={'1449:46.37,13.45'}	-- Karna Remtravel
G[9619]={'1449:71.64,75.97'}	-- Torwa Pathfinder
G[9623]={'1449:67.63,16.74'}
G[9660]={'FA 1425:14.10,43.60'}
G[9706]={'1446:67.04,24.02'}	-- Yorba Screwspigot
G[9796]={'FH 1411:42.73,67.24'}	-- Galgar
G[9836]={'1428:64.98,23.58'}	-- Mathredis Firestar
G[9862]={'1448:37.80,45.40 1448:39.80,49.20 1448:37.60,54.00','In cave'}	-- Jaedenar Legionnaire
G[9996]={'FH 1448:34.2,52.4'}
G[9997]={'1449:43.64,8.39'}
G[9998]={'1449:44.23,11.58'}	-- Shizzle
G[9999]={'1449:51.94,49.92'}
G[10079]={'FH 1441:32.24,22.16'}	-- Brave Moonhorn
G[10090]={'FA 1455:70.87,85.83'}	-- Belia Thundergranite
G[10118]={'FA 1438:56.25,92.44'}	-- Nessa Shadowsong
G[10136]={'FH 1458:47.45,73.37'}	-- Chemist Fuely
G[10176]={'FH 1411:43.28,68.54'}	-- Kaltunk
G[10181]={'FH 1458:58.04,91.77'}
G[10216]={'FA 1439:36.10,44.93'}
G[10219]={'FA 1439:36.62,45.59'}
G[10257]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Spire'}	-- Bijou
G[10260]={'1428:65.88,21.92'}	-- Kibler
G[10267]={'1428:65.24,24.00'}	-- Tinkee Steamboil
G[10300]={'FA 1452:63.06,59.45'}
G[10301]={'FA 1452:52.11,30.44'}
G[10302]={'1449:30.93,50.44'}	-- Krakle
G[10303]={'FH 1452:61.8,38.4'}
G[10304]={'1423:53.55,22.05'}
G[10305]={'1452:60.89,37.65'}
G[10306]={'FH 1448:34.6,52.6'}
G[10307]={'1452:61.90,38.31'}
G[10431]={'1452:61.34,38.93'}
G[10468]={'1452:61.61,38.61'}
G[10537]={'FH 1441:45.69,50.63'}	-- Cliffwatcher Longhorn
G[10616]={'FA 1429:81.38,66.11'}	-- Supervisor Raelen
G[10617]={'1441:15.1,23.1 1441:19.4,21.8 1441:20.1,27.8 1441:25.1,23.3 1441:25.1,33.7 1441:30.6,23.1 1441:29.5,33.8 1441:36.4,28.3 1441:38.,31.6 1441:41.3,35.8','Visits each camp in area'}	-- Galak Messenger
G[10618]={'FA 1452:49.91,9.85'}
G[10637]={'1452:61.0,38.6'}
G[10638]={'FH 1441:21.26,32.10'}	--Kanati Greycloud
G[10648]={'1448:39.06,22.23'}	-- Xavaric
G[10665]={'FH 1420:57.34,49.04 1420:57.34,49.04','Walks around graveyard'}	-- Junior Apothecary Holland
G[10666]={'FH 1420:56.08,52.48 1420:51.71,55.63 1420:47.64,57.42 1420:40.95,54.58','Frequently off the road'}-- Gordo
G[10667]={'1422:39.44,66.79'}
G[10684]={'FA 1452:56.18,44.52'}
G[10738]={'1452:69.6,38.2'}
G[10739]={'1422:53.71,64.75'}
G[10740]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Spire'}
G[10778]={'1422:38.36,54.08'}
G[10781]={'FH 1458:69.79,43.16'}	-- Royal Overseer Bauhaus
G[10782]={'FA 1453:48.47,30.55','Upstairs'}	-- Royal Factor Bathrilor
G[10837]={'FA 1420:83.0,69.0'}
G[10838]={'FA 1422:42.80,84.00'}	-- Commander Ashlam Valorfist
G[10839]={'1420:83.2,68.6'}
G[10840]={'1422:42.93,83.59'}
G[10877]={'FA 1455:49.49,11.14 1455:65.71,24.03 1455:71.16,49.54 1455:61.64,73.91 1455:44.59,80.36 1455:30.57,65.23 1455:23.94,45.42 1455:32.48,21.13 1455:57.44,45.97 1455:55.81,34.90 1455:47.53,31.36 1455:40.72,38.64 1455:46.37,47.45 1455:49.92,57.59 1455:55.19,52.99 1455:57.27,46.62','Walks round city'}	-- Courier Hammerfall
G[10878]={'FA 1457:59.77,66.78 1457:50.01,79.38 1457:44.24,77.55 1457:39.05,74.59 1457:38.83,57.74 1457:38.65,46.80 1457:31.20,41.51 1457:39.40,36.08 1457:43.52,40.81 1457:50.88,40.97 1457:61.77,40.61 1457:60.42,22.39 1457:65.22,16.18 1457:57.06,7.63 1457:53.53,13.97 1457:45.12,19.70 1457:38.69,21.07 1457:36.40,13.53 1457:33.76,15.77 1457:41.33,28.61 1457:62.70,54.82 1457:67.81,58.03 1457:63.65,71.62'}	-- Herald Moonstalker
G[10880]={'FH 1454:35.20,70.09 1454:37.00,73.00 1454:54.28,35.85 1454:43.45,37.34 1454:40.36,45.04 1454:38.83,57.77 1454:51.47,65.60 1454:52.08,57.38 1454:59.51,54.95 1454:49.42,48.34 1454:60.15,40.12','Patrols the city.'}	-- Warcaller Gorlach
G[10881]={'FH 1456:41.87,54.98 1456:38.13,62.07 1456:41.54,60.89 1456:36.30,53.95','Walking in a circle'}
G[10916]={'1448:60.8,5.8 1448:68.8,5.8 1452:28.4,37.8'}
G[10918]={'1452:63.8,73.8'}
G[10920]={'1448:51.10,81.79'}
G[10921]={'1448:50.91,81.67'}
G[10922]={'1448:51.09,82.14'}
G[10924]={'1448:50.92,81.62'}
G[10926]={'1423:36.40,90.80'}
G[10927]={'1422:49.04,78.90'}
G[10929]={'1452:54.6,51.2'}
G[10976]={'1422:39.4,66.8'}
G[11016]={'1448:36.18,55.55'}
G[11019]={'1448:51.29,82.04'}
G[11020]={'1448:38.48,50.45'}
G[11033]={'1423:80.63,58.10'}
G[11034]={'1423:81.6,58.0'}
G[11036]={'1423:81.72,57.83'}	-- Leonid Barthalomew the Revered
G[11039]={'1423:81.39,59.85'}
G[11048]={'FH 1458:70.08,29.88'}	-- Victor Ward
G[11049]={'FH 1458:70.06,30.56'}	-- Rhiannon Davis
G[11053]={'FA 1422:42.93,84.50'}
G[11055]={'FH 1420:83.00,71.80'}
G[11056]={'FA 1422:42.60,83.80'}
G[11057]={'FH 1420:83.2,69.2'}
G[11063]={'1423:81.40,59.80'}
G[11079]={'FA 1452:51.94,30.35'}
G[11140]={'1423:14.47,33.65'}
G[11216]={'1422:70.2,73.8'}
G[11218]={'FA 1439:44.37,76.37'}
G[11219]={'FA 1440:27.26,35.58'}	-- Liladris Moonriver
G[11259]={'FH 1443:55.4,55.8'}
G[11317]={'FH 1443:22.6,72.8'}
G[11378]={'FH 1411:44.62,68.65'}	-- Foreman Thazz'ril
G[11397]={'FA 1453:20.69,50.08'}	-- Nara Meideros
G[11401]={'FA 1457:39.52,81.19'}	-- Priestess Alathea
G[11406]={'FA 1455:26.97,7.31'}	-- High Priest Rohan
G[11407]={'FH 1412:46.96,58.82'}	-- Var'jun
G[11438]={'1443:62.26,38.91'}
G[11548]={'1447:11.41,78.17'}
G[11554]={'1448:50.96,84.98'}
G[11556]={'1452:27.75,34.52'}
G[11558]={'1448:65.42,2.67'}
G[11596]={'1443:60.87,61.91'}
G[11610]={'1422:51.95,28.01'}
G[11615]={'FH 1420:83.20,72.40'}
G[11616]={'FA 1422:43.48,84.88'}
G[11625]={'1443:66.63,37.58'}
G[11626]={'1443:45.33,75.41'}
G[11629]={'1452:61.32,38.92'}
G[11711]={'FA 1439:45.95,90.32'}
G[11715]={'FA 1443:68.42,8.91'}
G[11754]={'1452:61.6,38.4'}
G[11755]={'1452:61.0,38.4'}
G[11758]={'1446:52.82,27.41'}	-- Andi Lynn
G[11799]={'1450:36.51,40.11'}
G[11801]={'1450:51.69,44.98'}
G[11802]={'1450:56.21,30.64','Upstairs'}
G[11806]={'FA 1440:26.59,36.72'}	-- Sentinel Onaeya
G[11807]={'FA 1426:30.23,47.24 1426:30.84,48.40 1426:30.93,50.66 1426:31.31,44.46 1426:30.78,45.40','Sometimes walks path'}	-- Tristane Shadowstone
G[11811]={'1446:65.24,18.58'}	-- Narain Soothfancy
G[11814]={'FH 1411:56.12,74.24'}	-- Kali Remik
G[11820]={'FH 1440:71.39,67.63'}	-- Locke Okarr
G[11821]={'FH 1442:73.24,94.89'}	-- Darn Talongrip
G[11832]={'1450:36.2,41.8'}
G[11833]={'FH 1456:70.49,31.80','Walks in area'}	-- Rahauro
G[11834]={'FH 947:0.00,0.00 1454:52.66,49.06>947','Ragefire Chasm'}	-- Maur Grimtotem
G[11856]={'FH 1442:73.48,85.59'}	-- Kaya Flathoof
G[11857]={'FH 1413:35.19,27.79'}	-- Makaba Flathoof
G[11860]={'FH 1442:47.20,61.15'}	-- Maggran Earthbinder
G[11861]={'FH 1442:47.21,64.05'}	-- Mor'rogal
G[11862]={'FH 1442:47.22,64.37','Walks near'}	-- Tsunaman
G[11863]={'1443:38.91,27.22'}
G[11864]={'FH 1442:47.46,58.38'}	-- Tammra Windfield
G[11877]={'FH 1443:25.0,72.2'}
G[11940]={'FA 1429:47.36,41.84'}	-- Merissa Stilwell NOTE only available to those who purchased the Original WoW Collectors Edition and have it tied to their account.
G[11941]={'FA 1426:30.08,71.67'}	-- Yori Crackhelm NOTE only available to those who purchased the Original WoW Collectors Edition and have it tied to their account.
G[11942]={'FA 1438:58.81,44.41'}	-- Orenthil Whisperwind NOTE only available to those who purchased the Original WoW Collectors Edition and have it tied to their account.
G[11945]={'FH 1420:32.13,66.52'}	-- Claire Willower NOTE only available to those who purchased the Original WoW Collectors Edition and have it tied to their account.
G[12042]={'1450:52.40,40.60'}	-- Loganaar
G[12277]={'1443:33.86,53.59'}
G[12336]={'FA 1453:42.58,24.23','Cathedral basement'}	-- Brother Crowley
G[12384]={'1423:14.46,33.56'}
G[12425]={'FA 1422:43.63,84.46'}
G[12576]={'FH 1441:31.8,21.6'}
G[12676]={'1440:77.70,66.20 1440:75.90,69.70 1440:73.20,70.70 1440:70.30,73.80'}	-- Sharptalon
G[12677]={'1440:54.35,54.95 1440:52.22,54.41 1440:56.14,55.45 1440:57.84,55.89 1440:60.90,51.46 1440:62.43,49.78', 'Patrols the area'}	-- Shadumbra
G[12678]={'1440:43.12,63.38 1440:42.72,63.18 1440:40.86,66.34 1440:39.99,65.89 1440:39.78,62.85 1440:41.69,68.07 1440:43.70,68.84', 'Patrols the area'}	-- Ursangous
G[12696]={'FH 1440:73.78,61.46'}	-- Senani Thunderheart
G[12717]={'FH 1440:12.06,34.63','Can be on patrol'}	-- Muglash
G[12718]={'FH 1440:70.01,71.15'}	-- Gurda Ragescar
G[12719]={'FH 1440:11.69,34.91'}	-- Marukai
G[12721]={'FH 1440:11.65,34.85'}	-- Mitsuwa
G[12724]={'FH 1440:73.06,61.48'}	-- Pixel
G[12736]={'FH 1440:11.56,34.29'}	-- Je'neu Sancrea
G[12737]={'FH 1440:73.66,60.00'}	-- Mastok Wrilehiss
G[12738]={'FA 1426:24.98,75.94'}	-- Nori Pridedrift
G[12757]={'FH 1440:11.90,34.54'}	-- Karang Amakkar
G[12759]={'1440:48.39,69.91','patrols in the vicinity'}	-- Tideress
G[12816]={'FH 1442:71.25,95.02'}	-- Xen'Zilla
G[12818]={'FH 1440:41.52,34.48','In the cave'}	-- Ruul Snowhoof
G[12837]={'FH 1440:74.12,60.91'}	-- Yama Snowhoof
G[12858]={'FH 1440:68.34,75.29'}	-- Torek
G[12862]={'FH 1440:71.04,68.22','Moves up and down the tower'}	-- Warsong Scout
G[12863]={'FH 1440:12.22,34.21'}	-- Warsong Runner
G[12864]={'FH 1440:94.56,47.59 1440:88.96,48.80 1440:82.32,52.88 1440:78.36,55.83','Patrols the road'}	-- Warsong Outrider
G[12866]={'1413:49.01,94.94'}	-- Myriam Moonsinger
G[12867]={'FH 1440:71.10,68.11'}	-- Kuray'bin
G[12876]={'947:0.00,0.00 1440:14.09,14.87>947','Blackfathom Deeps'}	-- Baron Aquanis
G[12877]={'FH 1440:73.03,62.47'}	-- Ertog Ragetusk
G[12919]={'1445:58.54,59.93'}
G[12920]={'FH 1417:73.4,36.8'}
G[12939]={'FA 1445:67.75,48.97'}
G[12997]={'FA 947:0.00,0.00 1455:76.19,51.00>947','Deeprun Tram Ironforge end'}	-- Monty
G[13018]={'FA 947:0.00,0.00 1453:51.77,12.08>947','Deeprun Tram Stormwind end'}	-- Nipsy
G[13019]={'1443:55.2,30.0'}
G[13220]={'1451:81.84,18.97'}
G[13278]={'1447:79.29,73.71'}
G[13283]={'FA 1453:78.34,57.15'}	-- Lord Tony Romano
G[13417]={'FH 1454:38.66,35.87'}	-- Sagorne Creststrider
G[13418]={'HV FH 1454:53.34,66.48'}	-- Kaymard Copperpinch
G[13429]={'HV FH 1458:68.24,38.84'}	-- Nardstrum Copperpinch
G[13431]={'HV FH 1456:43.80,58.82'}	-- Whulwert Copperpinch
G[13433]={'HV FA 1455:33.71,67.22'}	-- Wulmort Jinglepocket
G[13435]={'HV FA 1453:55.00,59.07'}	-- Khole Jinglepocket
G[13444]={'HV FA 1455:33.22,65.42'}	-- Greatfather Winter
G[13445]={'HV FH 1454:52.49,69.21'}	-- Great-father Winter
G[13636]={'HV 1416:35.44,72.42'}	-- Strange Snowman
G[13656]={'1443:62.16,39.56'}
G[13698]={'FA 1443:64,10.4'}
G[13717]={'1443:46.34,86.74'}
G[13841]={'FA 1416:39.55,81.21'}
G[13843]={'FA 1455:32.42,63.43'}
G[14325]={'947:0.00,0.00','Dire Maul North'}
G[14368]={'947:0.00,0.00','Dire Maul North'}
G[14374]={'FA 1444:31.45,44.65'}
G[14392]={'FH 1454:51.6,78.6'}
G[14436]={'1428:12.60,31.60'}
G[14437]={'1428:12.60,31.60'}
G[14450]={'FA 1453:47.34,38.20'}	-- Orphan Matron Nightingale
G[14451]={'FH 1454:70.71,25.21'}	-- Orphan Matron Battlewail
G[14463]={'1419:34.00,50.20'}
G[14470]={'1448:41.40,45.00'}
G[14494]={'1423:20.8,18.4'}
G[14504]={'947:0.00,0.00 1444:59.12,45.18>947','Dire Maul'}
G[14522]={'1448:36.20,44.60'}	-- Ur'dan
G[14624]={'1427:38.79,28.49'}	-- Master Smith Burninate
G[14625]={'1427:38.12,26.97'}	-- Overseer Oilfist
G[14626]={'1427:38.97,27.51'}	-- Taskmaster Scrange
G[14627]={'1427:38.57,27.81'}	-- Hansel Heavyhands
G[14628]={'1427:38.35,27.76'}	-- Evonice Sootsmoker
G[14634]={'1427:37.73,26.56'}	-- Lookout Captain Lolo Longstriker
G[14636]={''}	-- Chambermaid Pillaclencher *** Not in game yet
G[14637]={'1444:44.81,43.36'}
G[14720]={'FH 1454:52.4,77.8'}
G[14722]={'FA 1453:44.27,73.98','Upstairs'}	-- Clavicus Knavingham
G[14723]={'FA 1455:43.23,31.59'}	-- Mistina Steelshield
G[14724]={'FA 1455:74.09,48.21'}	-- Bubulo Acerbus
G[14725]={'FA 1457:64.04,23.01'}	-- Raedon Duskstriker
G[14726]={'FH 1454:63.61,51.24'}	-- Rashona Straglash
G[14727]={'FH 1454:37.69,87.88'}	-- Vehena
G[14728]={'FH 1456:43.05,42.73'}	-- Rumstag Proudstrider
G[14729]={'FH 1458:71.65,29.27'}	-- Ralston Farnsley
G[14731]={'FH 1425:78.14,81.39'}	-- Lard
G[14736]={'FH 1425:78.20,81.17'}	-- Primal Torntusk
G[14737]={'FH 1425:77.52,80.35 1425:77.23,80.13'}	-- Smith Slagtree
G[14738]={'FH 1425:79.40,79.07'}	-- Otho Moji'ko
G[14739]={'FH 1425:78.81,78.24'}	-- Mystic Yayo'jin
G[14740]={'FH 1425:80.34,81.54'}	-- Katoom the Angler
G[14741]={'FH 1425:79.16,79.53'}	-- Huntsman Markhor
G[14753]={'FA 1440:61.6,83.8'}	-- Illiyana Moonblaze
G[14754]={'FH 1413:46.65,8.38'}	-- Kelm Hargunth
G[14822]={'HF 1429:42.13,69.00'}	-- Sayge  (Elwyn)
G[14828]={'HF 1429:41.50,68.90'}	-- Gelvas Grimegate  (Elwyn)
G[14829]={'HF 1429:40.20,69.50'}	-- Yebb Neblegear  (Elwyn)
G[14832]={'HF 1429:40.50,69.90'}	-- Kerri Hicks  (Elwyn)
G[14833]={'HF 1429:43.60,70.80'}	-- Chronos (Elwyn)
G[14841]={'HF 1429:41.70,70.70'}	-- Rinling (Elwyn)
G[14842]={'HG FA 1455:31.84,78.04 1455:23.41,62.77 1455:24.83,34.70 1455:29.19,58.86 1455:29.00,68.34 1455:34.87,74.93 1455:50.39,82.29'}	-- Melnan Darkstone
G[14843]={'HG FH 1454:52.20,66.89 1454:50.24,63.32 1454:45.21,60.48 1454:45.61,68.76 1454:51.49,76.96'}	-- Kruban Darkblade
G[14847]={'HF 1429:41.30,70.00'}	-- Professor Thaddeus Paleo (Elwyn)
G[14871]={'HF 1429:43.30,70.30','Runs around area'}	-- Morja (Elwyn)
G[14875]={'1434:15.04,15.13'}	-- Molthor
G[14902]={'1434:15.31,14.43'}	-- Jin'rokh the Breaker
G[14903]={'1434:15.34,16.13','Upstairs'}	-- Al'tabim the All-Seeing
G[14904]={'1434:15.30,16.02'}	-- Maywiki of Zuldazar
G[14905]={'1434:14.09,13.72'}	-- Falthir the Sightless
G[14910]={'1434:15.26,15.51'}	-- Exzhal
G[14921]={'1434:15.07,16.00'}	-- Rin'wosho the Trader
G[14983]={'FA 1417:45.82,45.46'}	-- Field Marshal Oslight
G[14984]={'FA 1417:45.9,45.3'}
G[15011]={'HH FA 1446:66.58,22.30'}	-- Wagner Hammerstrike
G[15012]={'HH FH 1411:46.10,13.77'}	-- Javnir Nashak
G[15021]={'FH 1417:73.2,29.8'}
G[15022]={'FH 1417:73.5,29.8'}
G[15042]={'947:0.00,0.00 1434:53.85,17.58>947',"Zul'Gurub"}	-- Zanza the Restless
G[15070]={'1434:14.50,15.83'}	-- Vinchaxa
G[15078]={'HX 1434:27.40,76.82'}	-- Jang
G[15079]={'HX 1434:27.34,76.87'}	-- Fishbot 5000
G[15116]={'HX FH 1454:52.48,72.80'}	-- Grinkle
G[15119]={'HX FA 1455:28.18,74.95'}	-- Barrus
G[15165]={'1446:66.56,22.27'}	-- Haughty Modiste
G[15180]={'1451:49.50,36.40'}	-- Baristolth of the Shifting Sands
G[15181]={'1451:49.2,34.2'}
G[15182]={'1451:50.8,33.6'}
G[15192]={'1446:65.23,50.00'}	-- Anachronos
G[15197]={'FH 1420:55.56,69.88'}	-- Darkcaller Yanka
G[15199]={'FA 1424:50.00,57.32'}	-- Sergeant Hartman
G[15278]={'1941:38.21,20.83'}
G[15279]={'1941:39.23,21.45'}
G[15280]={'1941:39.47,20.55'}
G[15281]={'1941:35.36,22.51'}
G[15283]={'1941:38.94,21.44'}
G[15284]={'1941:39.42,20.38'}
G[15285]={'1941:38.93,20.02'}
G[15295]={'1941:38.76,19.36'}
G[15296]={'1941:38.27,19.12'}
G[15297]={'1941:37.18,18.95'}
G[15298]={'1941:30.43,27.86'}
G[15301]={'FH 1941:40.42,32.21'}
G[15309]={'FH 1454:71.42,22.80'}	-- Spoops
G[15310]={'FA 1453:47.64,35.32'}	-- Jesper
G[15350]={'FH 1454:80.68,30.54 1456:57.84,76.34 1413:46.71,8.67 1416:63.09,59.88 1458:58.31,97.87 1417:73.49,29.13'}	-- Horde Warbringer
G[15351]={'FA 1455:69.68,89.64 1453:79.54,18.18 1457:58.00,34.21 1416:39.28,82.33 1417:45.66,45.75 1440:61.94,83.83'}	-- Alliance Brigadier General
G[15362]={'HQ 947:0.00,0.00 1435:68.81,59.27>947',"The Temple of Atal'Hakkar, Near to the Shade of Eranikus"}
G[15383]={'FA 1455:64.41,67.30'}	-- Sergeant Stonebrow
G[15395]={'1448:64.78,8.22'}
G[15397]={'FH 1941:43.68,71.30'}
G[15398]={'FH 1941:34.06,80.02'}
G[15399]={'FH 1941:60.32,62.77'}
G[15400]={'FH 1941:59.52,62.60'}
G[15401]={'1941:36.70,57.45'}
G[15402]={'FH 1941:54.28,70.97'}
G[15403]={'1941:48.16,45.99'}
G[15404]={'FH 1941:36.36,66.77'}
G[15405]={'1941:44.63,53.14'}
G[15406]={'FH 1941:70.52,72.33'}
G[15407]={'1941:62.2,79.6'}
G[15409]={'1941:35.0,84.6'}
G[15416]={'FH 1941:50.33,50.76'}
G[15417]={'FH 1941:44.72,69.63'}
G[15418]={'FH 1941:47.25,46.31'}
G[15431]={'FA 1455:65.00,65.33'}	-- Corporal Carnes
G[15432]={'FA 1455:63.89,68.41'}	-- Dame Twinbraid
G[15433]={'1941:48.15,47.65'}
G[15434]={'FA 1455:70.93,72.64'}	-- Private Draxlegauge
G[15437]={'FA 1455:71.93,71.31'}	-- Master Nightsong
G[15445]={'FA 1455:70.87,71.85'}	-- Sergeant Major Germaine
G[15446]={'FA 1455:57.63,76.38'}	-- Bonnie Stoneflayer
G[15448]={'FA 1455:58.51,75.22'}	-- Private Porter
G[15450]={'FA 1455:59.02,75.83'}	-- Marta Finespindle
G[15451]={'FA 1455:55.39,76.24'}	-- Sentinel Silversky
G[15452]={'FA 1455:55.13,77.68'}	-- Nurse Stonefield
G[15453]={'FA 1455:54.20,77.83'}	-- Keeper Moonshade
G[15455]={'FA 1455:71.02,69.87'}	-- Slicky Gastronome
G[15456]={'FA 1455:71.39,70.33'}	-- Sarah Sadwhistle
G[15457]={'FA 1455:71.55,69.12'}	-- Huntress Swiftriver
G[15459]={'FH 1454:31.64,66.67'}	-- Miner Cromwell
G[15460]={'FH 1454:31.15,65.02'}	-- Grunt Maug
G[15469]={'FH 1454:31.27,66.11'}	-- Senior Sergeant T'kelah
G[15477]={'FH 1454:33.15,70.44'}	-- Herbalist Proudfeather
G[15502]={'947:0.00,0.00 1451:29.06,93.46>947',"Ahn'Qiraj"}	-- Andorgos
G[15503]={'947:0.00,0.00 1451:29.06,93.46>947',"Ahn'Qiraj"}	-- Kandrostrasz
G[15504]={'947:0.00,0.00 1451:29.06,93.46>947',"Ahn'Qiraj"}	-- Vethsera
G[15508]={'FH 1454:33.43,69.26'}	-- Batrider Pele'keiki
G[15512]={'FH 1454:32.90,68.49'}	-- Apothecary Jezel
G[15513]={'1941:39.05,20.01'}
G[15515]={'FH 1454:35.60,73.30'}	-- Skinner Jamani
G[15522]={'FH 1454:34.14,72.76'}	-- Sergeant Umala
G[15525]={'FH 1454:35.21,72.51'}	-- Doctor Serratus
G[15528]={'FH 1454:31.05,74.12'}	-- Healer Longrunner
G[15529]={'FH 1454:31.23,75.09'}	-- Lady Callow
G[15532]={'FH 1454:31.62,75.78'}	-- Stoneguard Clayhoof
G[15533]={'FH 1454:28.83,67.40'}	-- Bloodguard Rawtar
G[15534]={'FH 1454:29.13,68.84'}	-- Fisherman Lin'do
G[15535]={'FH 1454:28.83,68.35'}	-- Chief Sharpclaw
G[15549]={'HL 947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Depths'}	-- Elder Morndeep
G[15556]={'HL 947:0.00,0.00 1443:29.86,62.53>947','Maraudon'}	-- Elder Splitrock
G[15557]={'HL 1428:82.19,46.47'}	-- Elder Rumblerock
G[15558]={'HL 1432:33.32,46.55'}	-- Elder Silvervein
G[15559]={'HL 1425:50.01,48.05'}	-- Elder Highpeak
G[15560]={'HL 947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Spire'}	-- Elder Stonefort
G[15561]={'HL 1421:44.98,41.14'}	-- Elder Obsidian
G[15562]={'HL 1453:21.41,53.89'}	-- Elder Hammershout
G[15563]={'HL 1419:58.75,51.70'}	-- Elder Bellowrage
G[15564]={'HL 1458:66.64,38.22'}	-- Elder Darkcore
G[15565]={'HL 1429:39.79,63.66'}	-- Elder Stormbrow
G[15566]={'HL 1423:81.51,60.52'}	-- Elder Snowcrown
G[15567]={'HL 1427:21.27,79.11'}	-- Elder Ironband
G[15568]={'HL 1420:61.88,53.84'}	-- Elder Graveborn
G[15569]={'HL 1426:46.82,51.61'}	-- Elder Goldwell
G[15570]={'HL 1451:23.09,11.84'}	-- Elder Primestone
G[15572]={'HL 1411:53.23,43.65'}	-- Elder Runetotem
G[15573]={'HL 1446:36.30,80.54'}	-- Elder Ragetotem
G[15574]={'HL 1452:61.45,37.75'}	-- Elder Stonespire
G[15575]={'HL 1412:48.41,53.44'}	-- Elder Bloodhoof
G[15576]={'HL 1434:27.62,74.26'}	-- Elder Winterhoof
G[15577]={'HL 1436:56.64,47.07','Top of the Tower'}	-- Elder Skychaser
G[15578]={'HL 947:0.00,0.00 1446:38.72,20.00>947',"Zul'Farrak"}	-- Elder Wildmane
G[15579]={'HL 1454:41.13,33.89'}	-- Elder Darkhorn
G[15580]={'HL 1456:72.99,23.38'}	-- Elder Proudhorn
G[15581]={'HL 1444:76.71,37.90'}	-- Elder Grimtotem
G[15582]={'HL 1413:62.65,36.74'}	-- Elder Windtotem
G[15583]={'HL 1449:50.37,76.16'}	-- Elder Thunderhorn
G[15584]={'HL 1441:45.42,50.08'}	-- Elder Skyseer
G[15585]={'HL 1428:64.45,24.06'}	-- Elder Dawnstrider
G[15586]={'HL 1446:51.47,27.85'}	-- Elder Dreamseer
G[15587]={'HL 947:0.00,0.00 1444:59.12,45.18>947','Dire Maul'}	-- Elder Mistwalker
G[15588]={'HL 1413:45.11,57.88'}	-- Elder High Mountain
G[15592]={'HL 1423:39.68,75.38'}	-- Elder Windrun
G[15593]={'HL 947:0.00,0.00 1435:68.81,59.27>947',"The Temple of Atal'Hakkar"}	-- Elder Starsong
G[15594]={'HL 947:0.00,0.00 1422:69.93,74.01>947','Scholomance'}	-- Elder Moonstrike
G[15595]={'HL 1438:57.33,60.79'}	-- Elder Bladeleaf
G[15596]={'HL 1434:53.12,18.46'}	-- Elder Starglade
G[15597]={'HL 1413:51.40,30.68'}	-- Elder Moonwarden
G[15598]={'HL 1457:33.48,14.29'}	-- Elder Bladeswift
G[15599]={'HL 1451:48.97,37.65'}	-- Elder Bladesing
G[15600]={'HL 1447:72.53,85.08'}	-- Elder Skygleam
G[15601]={'HL 1439:36.81,46.75'}	-- Elder Starweave
G[15602]={'HL 1422:65.97,47.82'}	-- Elder Meadowrun
G[15603]={'HL 1448:37.72,53.01'}	-- Elder Nightwind
G[15604]={'HL 1441:79.20,77.05'}	-- Elder Morningdew
G[15605]={'HL 1440:35.54,48.91'}	-- Elder Riversong
G[15606]={'HL 1452:55.62,43.64'}	-- Elder Brightspear
G[15607]={'HL 947:0.00,0.00 1423:30.85,20.08>947 947:0.00,0.00 1423:47.91,23.87>947','Stratholme'}	-- Elder Farwhisper
G[15624]={'HQ 1438:37.5,47.9'}
G[15670]={'1941:28.2,60.4'}
G[15685]={'1446:73.8,47.6'}	-- Southsea Kidnapper
G[15692]={'1427:73.80,25.00 1427:72.00,33.20 1427:65.00,34.80 1427:70.20,43.40 1427:67.80,50.80 1427:66.20,54.20'}	-- Dark Iron Kidnapper
G[15693]={'HQ 1451:25.9,91.0'}
G[15700]={'FH 1454:36.10,74.39 1454:31.00,69.10 1454:32.92,72.47 1454:29.50,64.25'}	-- Warlord Gorchukk
G[15701]={'FA 1455:56.93,78.63 1455:59.16,84.73 1455:64.80,78.61 1455:69.28,72.09 1455:66.39,67.32 1455:61.19,73.59'}	-- Field Marshal Snowfall
G[15702]={'FH 1456:39.88,51.66'}	-- Senior Sergeant Taiga
G[15703]={'FH 1458:62.58,47.69'}	-- Senior Sergeant Grimsford
G[15704]={'FH 1454:51.55,66.36'}	-- Senior Sergeant Kai'jin
G[15707]={'FA 1455:27.51,73.34'}	-- Master Sergeant Fizzlebolt
G[15708]={'FA 1453:54.07,59.68'}	-- Master Sergeant Maclure
G[15709]={'FA 1457:41.97,41.55'}	-- Master Sergeant Moonshadow
G[15731]={'FA 1455:61.24,69.34'}	-- Darnassus Commendation Officer
G[15732]={'HV 1426:53.17,35.62 1453:62.26,60.75 1411:49.99,13.59 1446:53.54,28.00 1437:9.21,58.36 1420:61.02,59.35'}	-- Wonderform Operator
G[15733]={'FA 1455:58.61,72.64'}	-- Gnomeregan Commendation Officer
G[15734]={'FA 1455:61.10,76.96'}	-- Ironforge Commendation Officer
G[15735]={'FA 1455:63.34,69.31'}	-- Stormwind Commendation Officer
G[15736]={'FH 1454:30.83,73.64'}	-- Orgrimmar Commendation Officer
G[15737]={'FH 1454:30.04,70.06'}	-- Darkspear Commendation Officer
G[15738]={'FH 1454:30.44,65.55'}	-- Undercity Commendation Officer
G[15739]={'FH 1454:32.97,71.62'}	-- Thunder Bluff Commendation Officer
G[15761]={'FH 1454:46.31,35.12'}	-- Officer Vu'Shalay
G[15762]={'FA 1457:38.23,38.64'}	-- Officer Lunalight
G[15763]={'FA 1455:69.74,46.03'}	-- Officer Porterhouse
G[15764]={'FA 1455:43.26,46.45'}	-- Officer Ironbeard
G[15765]={'FH 1454:42.53,38.73'}	-- Officer Redblade
G[15766]={'FA 1453:55.24,64.73'}	-- Officer Maloof
G[15767]={'FH 1456:42.38,56.97'}	-- Officer Thunderstrider
G[15768]={'FH 1458:61.90,45.31'}	-- Officer Gothena
G[15799]={'1451:49.6,37.2'}
G[15864]={'HL 1450:53.65,35.26'}	-- Valadar Starsong
G[15871]={'HL 1455:29.19,17.07'}	-- Elder Bronzebeard
G[15895]={'HL 1456:71.12,28.21 1453:23.22,53.25 1457:32.59,12.00 1455:28.85,16.24 1458:65.63,36.00 1454:41.66,31.98'}	-- Lunar Festival Harbinger
G[15909]={'HL 1450:53.79,35.32'}	-- Fariel Starsong
G[15920]={'FH 1941:29.90,58.52'}
G[15921]={'FH 1941:36.35,66.62'}
G[15924]={'FH 1941:67.85,56.48'}
G[15939]={'FH 1941:43.34,70.82'}
G[15941]={'FH 1941:45.19,56.44'}
G[15942]={'FH 1941:46.93,71.78'}
G[15945]={'FH 1941:44.88,61.03'}
G[15951]={'FH 1941:60.32,61.38','Up ramp'}
G[15969]={'FH 1941:68.71,46.95'}
G[15970]={'FH 1941:55.70,54.50'}
G[16001]={'HA FA 1457:41.96,42.34'}	-- Aldris Fourclouds
G[16002]={'HA FA 1453:54.32,65.96'}	-- Colara Dean
G[16003]={'HA FH 1420:60.66,59.49'}	-- Deathguard Tor
G[16004]={'HA FH 1458:66.94,45.22'}	-- Elenia Haydon
G[16005]={'HA FA 1453:57.07,59.60'}	-- Lieutenant Jocryn Heldric
G[16007]={'HA FH 1454:51.29,70.20'}	-- Orok Deathbane
G[16008]={'HA FH 1456:44.77,60.11'}	-- Temma of the Wells
G[16009]={'HA FA 1455:32.67,66.18'}	-- Tormek Stoneriver
G[16012]={'FH 1454:34.95,38.28'}	-- Mokvar
G[16013]={'FA 1455:43.54,52.65'}	-- Deliana
G[16014]={'1446:52.4,27.2'}
G[16016]={'HL 947:0.00,0.00 1423:30.85,20.08>947','Stratholme Main Entrance'}	-- Anthion Harmon
G[16031]={'947:0.00,0.00 1423:47.91,23.87>947','Stratholme Service Entrance'}	-- Ysida Harmon
G[16032]={'947:0.00,0.00 1444:59.12,45.18>947','Dire Maul'}	-- Falrin Treeshaper
G[16033]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Spire'}	-- Bodley
G[16075]={'HA 1453:78.67,17.45 1455:40.30,56.59 1457:38.13,80.51 1454:32.56,36.82 1458:55.20,89.96 1456:60.88,50.33'}	-- Kwee Q. Peddlefeet
G[16105]={'HA FA 1453:54.61,65.28'}	-- Aristan Mottar
G[16106]={'HA FA 1453:39.83,46.96'}	-- Evert Sorisam
G[16107]={'HA 1416:89.36,74.94'}	-- Apothecary Staffron Lerent
G[16108]={'HA FH 1458:66.69,44.72'}	-- Fenstad Argyle
G[16109]={'HA FH 1458:71.92,28.47'}	-- Mara Rennick
G[16144]={'FH 1941:38.15,73.55'}
G[16183]={'FH 1941:49,89'}
G[16187]={'1942:47.34,29.25'}
G[16189]={'1942:45.42,30.53'}
G[16191]={'1954:53.93,71.04'}
G[16192]={'FH 1941:54.37,50.72'}
G[16196]={'FH 1941:49.02,89.05'}
G[16197]={'FH 1942:46.55,28.38 1942:46.10,28.32','Walks between points'}
G[16198]={'FH 1942:47.66,34.86'}
G[16199]={'FH 1942:46.02,31.97'}
G[16200]={'FH 1942:46.03,33.57'}
G[16201]={'FH 1942:72.30,19.10'}
G[16202]={'FH 1942:72.50,32.13'}
G[16203]={'FH 1942:71.95,32.64','Up east ramp'}
G[16204]={'FH 1942:54.86,48.57'}
G[16205]={'FH 1942:48.91,31.32','Up ramp'}
G[16210]={'FH 1941:44.03,70.76'}
G[16213]={'1942:45.48,32.45'}
G[16219]={'FH 1942:69.40,15.18'}
G[16220]={'FH 1942:72.37,29.64'}
G[16224]={'FH 1942:47.25,28.54'}
G[16231]={'FH 1942:44.89,32.52'}
G[16237]={'FH 1942:60.29,35.63'}
G[16239]={'FH 1942:55.08,48.83'}
G[16240]={'FH 1942:54.83,48.35'}
G[16251]={'FH 1942:44.74,32.28'}
G[16252]={'FH 1942:44.77,32.44'}
G[16253]={'FH 1942:48.43,30.93'}
G[16261]={'FH 1941:43.69,71.55'}
G[16287]={'FH 1458:57.78,90.52'}
G[16289]={'FH 1942:44.85,32.81'}
G[16291]={'FH 1942:54.95,48.50'}
G[16293]={'FH 1942:31.44,48.32'}
G[16295]={'FH 1942:62.90,32.77'}
G[16314]={'1942:16.2,57.6'}
G[16362]={'FH 1941:44.19,85.47'}
G[16397]={'FH 1941:43.57,71.21'}
G[16462]={'FH 1942:72.20,29.77'}
G[16463]={'FH 1942:72.32,31.26'}
G[16464]={'FH 1942:72.62,31.56'}
G[16475]={'1943:82.96,43.89'}
G[16477]={'1943:80.42,45.89'}
G[16480]={'FH 1942:46.40,56.43'}
G[16500]={'1943:79.59,48.76'}
G[16501]={'1943:79.78,48.17'}
G[16502]={'1943:80.13,48.15'}
G[16514]={'1943:79.13,46.54'}
G[16522]={'1943:69.27,65.77'}
G[16535]={'1943:79.48,51.63'}
G[16546]={'1943:71.96,60.74'}
G[16551]={'1943:48.72,50.39'}
G[16553]={'1943:48.34,49.15'}
G[16554]={'1943:64.49,54.04'}
G[16601]={'FH 1942:57.54,14.94'}
G[16618]={'1954:79.50,58.22'} -- Innkeeper Velandra
G[16647]={'1954:74.40,47.14'}
G[16739]={'1947:59.51,18.72'} -- Caregiver Breel
G[16788]={'HM 1453:38.54,61.30 1455:63.58,24.69 1438:56.55,91.98 1454:42.63,34.31 1458:65.52,36.34 1456:21.50,25.87'}	-- Festival Flamekeeper
G[16802]={'FH 1954:53.81,20.22'}	-- Lor'themar Theron
G[16817]={'HM FA 1453:39.22,61.44 1455:63.84,25.54 1438:56.57,92.28'}	-- Festival Loremaster
G[16818]={'HM FH 1454:42.52,34.60 1458:66.51,38.06 1456:21.52,27.19'}	-- Festival Talespinner
G[16819]={'FA 1944:56.64,66.70'}	-- Force Commander Danath Trollbane
G[16820]={'FA 1944:50.91,60.19'}	-- Lieutenant Amadi
G[16841]={'FA 1419:58.31,55.86'}	-- Watch Commander Relthorn Netherwane
G[16924]={'1941:47.77,46.58'}
G[17071]={'1943:79.48,51.31'}
G[17101]={'1943:61.06,54.25'}
G[17110]={'1943:49.79,51.93'}
G[17114]={'1943:49.36,50.98'}
G[17116]={'1943:47.14,50.62'}
G[17121]={'1947:38.45,81.93'}
G[17214]={'1943:48.39,51.77'}
G[17215]={'1943:48.40,51.48'}
G[17232]={'1943:49.36,50.84'}
G[17240]={'1943:47.03,70.20'}
G[17241]={'1943:47.12,70.29'}
G[17242]={'1943:47.24,70.01'}
G[17246]={'1943:46.68,70.54','Walks a bit'}
G[17249]={'1434:28.13,75.89'} -- Landro Longshot
G[17311]={'1943:16.52,94.34'}
G[17360]={'1943:49.36,50.84'}
G[17361]={'1943:55.14,41.73'}
G[17362]={'1943:64.44,39.78'}
G[17363]={'1943:63.12,67.94'}
G[17364]={'1943:28.14,62.35'}
G[17440]={'1943:46.66,20.72'}
G[17441]={'1943:44.70,23.61'}
G[17442]={'1943:44.87,23.92'}
G[17443]={'1943:46.92,22.22'}
G[17445]={'1943:46.93,21.25'}
G[17483]={'1943:48.38,49.47'}
G[17488]={'1943:48.88,51.07'}
G[17509]={'1947:38.45,81.93'}
G[17584]={'1947:81.52,51.78'}
G[17849]={'1941:42.03,35.65'}
G[18931]={'1944:87.37,52.39'} -- Amish Wildhammer
G[19229]={'FA 1944:87.36,50.73'}  -- Commander Duron
G[19253]={'FH 1944:87.35,49.81'} -- Lieutenant General Orion
G[19254]={'FH 1419:58.11,55.95'} -- Warlord Dar'toon
G[19255]={'1944:55.93,36.66'}
G[19256]={'1944:57.96,41.26'}
G[19273]={'FH 1944:65.9,43.6'}
G[19308]={'FA 1944:54.57,62.79'}  -- Marshal Isildor
G[19456]={'FH 1941:37.59,86.23'}
if release >= 38835 and interface >= 20501 and release <= 38892 then
G[19942]={'1419:58.25,55.06'} --  Agent Proudwell only present buring prepatch event
end  
G[19945]={'FH 1941:37.59,86.23'}
G[20233]={'1943:79.07,46.62'}
G[23128]={'FH 1454:32.23,35.82'}	-- Master Pyreanor
G[44036]={'FH 1941:43.96,69.97'}
G[500001]={'FH 1412:53.85,80.49 A:5891'}	-- to handle the Minor Manifestation of Earth's in Durotar and Mulgore
G[500002]={'1457:41.61,43.19 A:14305'}	-- Human Orphan in Darnassus
G[500003]={'1432:48.50,14.50 A:14305'}	-- Human Orphan at the Stonewrought Dam
G[500004]={'1436:30.00,86.00 A:14305'}	-- Human Orphan at the Westfall Lighthouse
G[500005]={'1445:66.31,48.94 A:14305'}	-- Human Orphan for Jaina's Autograph
G[500006]={'1453:54.21,65.36 A:14305'}	-- Human Orphan for Ice Cream
G[500007]={'1453:47.36,38.53 A:14305'}	-- Human Orphan for turn-in
G[500008]={'1413:63.14,38.20 A:14444'}	-- Orcish Orphan at Ratchet
G[500009]={'1413:47.88,5.34 A:14444'}	-- Orcish Orphan at Mor'shan Rampart
G[500010]={'1458:65.99,36.81 A:14444'}	-- Orcish Orphan at Undercity
G[500011]={'1454:50.60,65.60 A:14444'}	-- Orcish Orphan for Ice Cream
G[500012]={'1456:59.16,51.77 A:14444'}	-- Orcish Orphan for Cairne
G[500013]={'1454:70.85,25.55 A:14444'}	-- Orcish Orphan for turn-in
G[500014]={'1453:47.36,38.53 1457:41.61,43.19 1432:48.50,14.50 1436:30.00,86.00 A:14305'}	-- Human Orphan in first quest set start
G[500015]={'1457:41.61,43.19 1432:48.50,14.50 1436:30.00,86.00 A:14305'}	-- Human Orphan in second quest set start
G[500016]={'1453:54.21,65.36 1445:66.31,48.94 1453:47.36,38.53 A:14305'}	-- Human Orphan in third quest set start
G[500017]={'1454:70.85,25.55 1413:63.14,38.20 1413:47.88,5.34 1458:65.99,36.81 A:14444'}	-- Orcish Orphan in first quest set start
G[500018]={'1413:63.14,38.20 1413:47.88,5.34 1458:65.99,36.81 A:14444'}	-- Orcish Orphan in second quest set start
G[500019]={'1454:70.85,25.55 1456:59.16,51.77 1454:50.60,65.60 A:14444'}	-- Orcish Orphan in third quest set start
G[500020]={'1456:38.36,63.42 A:15891'} 	-- Lunar Festival Herald for quest 8875
G[500021]={'1458:66.74,43.34 A:15891'} 	-- Lunar Festival Herald for quest 8874
G[500022]={'1454:50.98,70.54 A:15891'} 	-- Lunar Festival Herald for quest 8873
G[500023]={'1453:54.35,66.29 A:15892'} 	-- Lunar Festival Emissary for quest 8871
G[500024]={'1457:42.17,44.00 A:15892'} 	-- Lunar Festival Emissary for quest 8872
G[500025]={'1455:30.94,61.61 A:15892'} 	-- Lunar Festival Emissary for quest 8870
G[514828]={'HF 1412:37.20,37.70 A:14828'}	-- Gelvas Grimegate  (Mulgore)
G[514829]={'HF 1412:37.50,39.60 A:14829'}	-- Yebb Neblegear  (Mulgore)
G[514832]={'HF 1412:37.80,39.80 A:14832'}	-- Kerri Hicks (Mulgore)
G[514833]={'HF 1412:36.20,35.10 A:14833'}	-- Chronos (Mulgore)
G[514841]={'HF 1412:37.10,37.20 A:14841'}	-- Rinling (Mulgore)
G[514847]={'HF 1412:36.50,38.00 A:14847'}	-- Professor Thaddeus Paleo (Mulgore)
G[514871]={'HF 1412:35.90,35.30 A:14871','Runs around area'}	-- Morja (Mulgore)
G[700000]={'1431:75.43,46.72 A:576'}
G[700001]={'1426:53.16,35.62 A:15732'}
G[700002]={'1433:15.28,71.45 A:464'}
G[700003]={'1433:29.63,46.18 A:382'}
G[700004]={'FA 1432:33.15,49.33 A:1340'}
G[700005]={'1453:39.12,26.06 A:4982'}
G[700006]={'1431:73.27,32.61 A:840'}
G[700007]={'1432:36.89,42.37 A:1340'}
G[700008]={'1431:74.82,44.20 A:840'}
G[700009]={'FH 1941:29.90,58.52 A:15920'}
G[1000031]={'1433:84.51,47.05'}
G[1000033]={'1436:25.97,16.91'}
G[1000034]={'1436:40.63,17.03'}
G[1000035]={'1436:25.91,47.76'}
G[1000036]={'1436:40.51,47.80'}
G[1000047]={'1433:26.74,46.45'}	-- Wanted: Lieutenant Fangore (1000047) 
G[1000055]={'1429:72.66,60.33'}	-- A half-eaten body
G[1000056]={'1429:79.80,55.50'}	-- Rolf's corpse
G[1000059]={'1431:49.87,77.71'}
G[1000060]={'1433:29.63,46.17'}	-- Wanted: Gath'Ilzogg
G[1000061]={'1431:17.73,29.07'}	-- A Weathered Grave
G[1000068]={'1429:24.46,74.73'}	-- Wanted Poster
G[1000076]={'1433:63.26,49.83','Top of tower'}	-- An Empty Jar
G[1000256]={'1432:37.29,46.49'}
G[1000257]={'1432:56.06,13.25'}	-- Suspicious Barrel
G[1000259]={'1437:13.93,34.81'}
G[1000261]={'1437:13.51,41.38'}
G[1000269]={'1426:47.74,52.67'}	-- Guarded Thunder Ale Barrel
G[1000270]={'1426:47.71,52.69','In basement'}	-- Unguarded Thunder Ale Barrel
G[1000287]={'1434:43.77,9.44'}	-- Bookie Herod's Records
G[1000288]={'1434:49.66,7.60'}
G[1000711]={'1420:60.73,51.52'}	-- Wanted!
G[1001557]={'1420:66.64,44.88'}	-- Lillith's Dinner Table
G[1001561]={'1453:29.45,61.54'}	-- Sealed Crate
G[1001585]={'1432:50.58,14.30'}
G[1001586]={'1420:68.16,42.02'}	-- Crate of Candles
G[1001593]={'1421:58.38,34.81'}	-- Corpse Laden Boat
G[1001599]={'1421:67.87,24.85'}
G[1001609]={'1437:47.40,46.90'}
G[1001627]={'1421:49.90,60.33'}	-- Dalaran Crate
G[1001728]={'1424:62.81,18.73'}	-- Dusty Rug
G[1001740]={'FA 1416:58.31,67.93'}
G[1001763]={'FH 1424:62.62,20.73'}	-- WANTED
G[1001765]={'1416:39.18,14.68'}	-- Worn Wooden Chest
G[1001767]={'1424:52.76,53.44'}	-- Helcular's Grave
G[1002008]={'FH 1424:62.56,19.68'}	-- Dangerous!
G[1002059]={'1426:79.68,36.17'}	-- A Dwarven Corpse
G[1002076]={'1434:32.22,27.61'}	-- Bubbling Cauldron
G[1002083]={'1434:27.28,69.52'}	-- Bloodsail Correspondence
G[1002289]={'1434:32.52,81.95'}	-- Ruined Lifeboat
G[1002553]={'1435:22.80,48.10'}	-- A Soggy Scroll
G[1002555]={'1445:31.18,65.93'}	-- Musty Scroll
G[1002556]={'1425:80.74,46.41'}	-- Cortello's Treasure
G[1002560]={'1434:37.20,68.40 1434:35.60,71.70 1434:33.70,75.00 1434:33.20,77.90 1434:38.3,77.2 Q:594'}	-- Half-Buried Bottle
G[1002652]={'1437:51.28,7.96'}	-- Ebenezer Rustlocke's Corpse
G[1002688]={'1417:36.06,58.10'}	-- Keystone
G[1002701]={'1417:84.31,30.92','In far back of cave'}
G[1002702]={'1417:36.23,57.37'}	-- Stone of Inner Binding
G[1002703]={'FH 1417:28.83,59.64','In the crypt'}	-- Trollbane's Tomb
G[1002713]={'FA 1417:46.05,47.75'}	-- Wanted Board
G[1002734]={'1437:12.11,64.20'}
G[1002868]={'1418:53.03,33.95'}
G[1002875]={'1418:50.91,62.39'}
G[1002908]={'1412:53.74,48.18'}	-- Sealed Supply Crate
G[1003238]={'1413:57.15,9.00 1413:43.83,12.14 1413:37.90,16.16 1413:41.81,38.76 1413:45.01,62.21 1413:56.55,43.67 1413:54.71,37.20 1413:55.70,27.30 1413:55.78,20.01'}	-- Chen's Empty Keg
G[1003239]={'1411:59.25,57.65'}	-- Benedict's Chest
G[1003643]={'1436:41.52,66.73'}
G[1003972]={'1413:62.59,37.47'}	-- WANTED (Baron Longshore)
G[1004141]={'1413:52.40,11.65'}	-- Control Console
G[1005619]={'1413:62.34,20.04'}	-- Flawed Power Stones
G[1006751]={'1438:42.62,76.07'}
G[1006752]={'1438:34.70,28.69'}
G[1007510]={'1438:60.77,68.48'}
G[1010076]={'1439:39.56,86.23'}
G[1012666]={'1439:38.59,86.13'}
G[1017182]={'1439:36.61,46.32'}
G[1017183]={'1439:41.96,28.70'}
G[1017184]={'1439:51.25,24.59'}
G[1017185]={'1439:41.43,80.65'}
G[1019024]={'1440:56.43,49.27'}
G[1019599]={'1442:26.7,10.9'}
G[1020805]={'1441:77.25,77.41'}
G[1020985]={'1445:55.37,25.99'}
G[1020992]={'1445:29.66,48.56'}
G[1021015]={'1445:29.69,47.66'}	-- Hoofprints
G[1021016]={'1445:29.69,47.66'}	-- Hoofprints
G[1021042]={'1445:29.82,48.19'}
G[1024776]={'1421:44.19,42.67'}	-- Yuriv's Tombstone
G[1032569]={'1435:47.77,39.44'}
G[1035251]={'1443:36.13,30.46'}
G[1050961]={'1443:56.55,17.76'}
G[1051708]={'1431:28.86,30.80'}
G[1061934]={'1411:38.90,58.20'}	-- Brazier of the Dormant Flame
G[1089931]={'1416:79.30,66.70'}
G[1112888]={'1421:65.36,24.81'}	-- Dusty Shelf
G[1112948]={'1437:14.37,23.88'}
G[1113791]={'1421:38.45,44.92'}
G[1138492]={'1417:62.53,33.74'}
G[1141980]={'1435:33.30,66.20'}
G[1142071]={'1446:52.39,26.97'}	-- Egg-O-Matic
G[1142127]={'1425:86.30,59.01'}	-- Rin'ji's Secret
G[1142151]={'1437:13.61,38.21'}
G[1142179]={'1444:26.23,52.34'}
G[1142194]={'1446:50.71,90.79 1446:53.10,95.90'}	-- Pirate's Treasure!
G[1142343]={'1446:37.7,81.5'}
G[1142702]={'1425:23.54,58.84'}	-- Venom Bottle (3)
G[1142703]={'1425:23.22,58.65'}	-- Venom Bottle (4)
G[1142704]={'1425:23.22,58.65'}	-- Venom Bottle (4)
G[1142705]={'1425:23.54,58.84'}	-- Venom Bottle (3)
G[1142706]={'1425:23.54,58.84'}	-- Venom Bottle (3)
G[1142707]={'1425:23.22,58.65'}	-- Venom Bottle (4)
G[1142708]={'1425:31.54,57.74'}	-- Venom Bottle (1)
G[1142709]={'1425:31.54,57.74'}	-- Venom Bottle (1)
G[1142710]={'1425:31.54,57.74'}	-- Venom Bottle (1)
G[1142711]={'1425:31.54,57.74'}	-- Venom Bottle (1)
G[1142712]={'1425:31.54,57.74'}	-- Venom Bottle (1)
G[1142713]={'1425:22.99,57.74'}	-- Venom Bottle (2)
G[1142714]={'1425:22.95,57.74'}	-- Venom Bottle (2)
G[1144063]={'1444:38.75,13.17'}
G[1148498]={'1427:41.24,25.69'}
G[1148504]={'1446:53.84,29.02'}
G[1149047]={'1427:39.11,39.18'}	-- Torch of Retribution
G[1156561]={'1429:24.58,78.24'}	-- Wanted Poster
G[1161504]={'1449:63.11,69.04'}	-- A Small Pack
G[1161505]={'1449:63.02,68.50'}	-- A Wrecked Raft
G[1164867]={'1418:3.76,47.42'}	-- WANTED
G[1164868]={'1418:3.97,46.77'}	-- KILL ON SIGHT
G[1164885]={'1448:40.72,78.26'}	-- Corrupted Night Dragon
G[1164886]={'1448:52.89,87.83'}	-- Corrupted Songflower
G[1164887]={'1448:50.00,80.00'}	-- Corrupted Windblossom
G[1164888]={'1448:40.15,85.20'}	-- Corrupted Whipper Root
G[1164909]={'1444:45.41,65.03'}
G[1164953]={'1444:73.30,56.28'}
G[1164955]={'1449:56.49,12.37'}
G[1164956]={'1449:23.77,59.16'}
G[1164957]={'1449:77.27,50.02'}
G[1171939]={'1448:45.94,85.22'}	-- Corrupted Songflower
G[1171942]={'1448:48.26,75.65'}	-- Corrupted Songflower
G[1173265]={'1427:65.60,62.14'}	-- Wooden Outhouse
G[1173284]={'1448:50.58,18.26'}	-- Corrupted Whipper Root
G[1173324]={'1448:50.58,30.43'}	-- Corrupted Night Dragon
G[1173327]={'1448:55.22,23.47'}	-- Corrupted Windblossom
G[1174594]={'1448:63.33,22.61'}	-- Corrupted Songflower
G[1174595]={'1448:63.92,6.09'}	-- Corrupted Songflower
G[1174596]={'1448:55.80,10.44'}	-- Corrupted Songflower
G[1174597]={'1448:50.58,13.91'}	-- Corrupted Songflower
G[1174598]={'1448:34.35,52.17'}	-- Corrupted Songflower
G[1174599]={'1448:55.80,6.96'}	-- Corrupted Windblossom
G[1174600]={'1448:57.54,20.00'}	-- Corrupted Windblossom
G[1174601]={'1448:45.36,18.26'}	-- Corrupted Windblossom
G[1174602]={'1448:38.79,21.95'}	-- Corrupted Windblossom
G[1174603]={'1448:34.35,48.70'}	-- Corrupted Windblossom
G[1174604]={'1448:38.99,59.13'}	-- Corrupted Windblossom
G[1174605]={'1448:49.43,12.18'}	-- Corrupted Whipper Root
G[1174606]={'1448:40.73,19.14'}	-- Corrupted Whipper Root
G[1174607]={'1448:43.05,46.96'}	-- Corrupted Whipper Root
G[1174608]={'1448:42.47,13.91'}	-- Corrupted Night Dragon
G[1174682]={'1449:43.58,8.39'}
G[1174684]={'1448:35.11,58.93'}	-- Corrupted Night Dragon
G[1174686]={'1448:34.05,60.24'}	-- Corrupted Whipper Root
G[1174708]={'1448:36.56,61.97'}	-- Corrupted Windblossom
G[1174709]={'1448:44.79,41.75'}	-- Corrupted Windblossom
G[1174712]={'1448:40.15,56.53'}	-- Corrupted Songflower
G[1174713]={'1448:40.15,44.35'}	-- Corrupted Songflower
G[1174848]={'1458:47.91,73.48'}	-- Testing Equipment
G[1175226]={'1439:35.99,70.97'}
G[1175227]={'1439:32.75,80.74'}
G[1175230]={'1439:31.23,87.39'}	-- Beached Sea Creature REINSERTED, needed for quest 4733
G[1175233]={'1439:41.86,31.57'}
G[1175265]={'1458:47.85,73.53'}	-- Testing Equipment
G[1175524]={'1439:47.31,48.74'}
G[1175586]={'1452:61.38,60.63'}
G[1175587]={'1452:59.04,59.76'}
G[1175704]={'1427:74.44,19.29'}	-- Singed Letter
G[1175894]={'1422:38.74,55.16'}
G[1175924]={'1422:47.37,49.65'}
G[1175925]={'1422:48.21,49.61'}
G[1175926]={'1422:47.78,50.73'}
G[1175927]={'1452:60.1,38.8'}
G[1176090]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Spire'}
G[1176091]={'1448:60.18,5.92'}
G[1176190]={'1439:37.14,62.11'}
G[1176191]={'1439:31.23,85.51'}
G[1176192]={'1422:39.4,66.7'}
G[1176196]={'1439:53.07,18.15'}
G[1176197]={'1439:44.21,20.71'}
G[1176198]={'1439:31.74,83.67'}
G[1176361]={'1422:37.19,56.87'}
G[1176392]={'1422:62.58,58.57'}
G[1176393]={'1422:53.00,65.70'}
G[1177289]={'1422:46.20,52.00'}
G[1177491]={'1422:48.32,31.95'}
G[1177786]={'1443:29.95,8.67'}
G[1177787]={'1443:36.08,30.48'}
G[1177904]={'1442:59.06,75.71'}	-- Wanted Poster: Besseleth
G[1179485]={'947:0.00,0.00','Alterac Valley'}	-- Broken Trap
G[1179551]={'1447:79.2,74.8'}	-- Hydraxis' Coffer
G[1179827]={'1427:37.66,26.48'}	-- Wanted/Missing/Lost & Found
G[1179880]={'947:0.00,0.00 1427:34.57,84.04>947 947:0.00,0.00 1428:31.86,50.45>947','Blackrock Spire'}	-- Drakkisath's Brand
G[1179913]={'1425:79.06,79.00'}	-- Call to Arms!
G[1180024]={'947:0.00,0.00 1436:40.68,79.58>947','The Deadmines'}	-- Mysterious Deadmines Chest
G[1180025]={'1429:84.80,64.40'}	-- Mysterious Eastvale Haystack
G[1180055]={'947:0.00,0.00 1414:52.40,55.19>947','The Wailing Caverns'}	-- Mysterious Wailing Caverns Chest
G[1180056]={'1412:34.98,61.55'}	-- Mysterious Tree Stump
G[1180366]={'947:0.00,0.00 1434:53.85,17.58>947',"Zul'Gurub"}	-- Battered Tackle Box
G[1180570]={'1424:51.34,59.02'}	-- Keg
G[1180633]={'1451:28.70,89.10'}	-- Crystalline Tear
G[1180642]={'1421:46.2,86.7'}
G[1180652]={'1446:59.6,95.6','Island south of here, off map'}	-- Freshly Dug Dirt
G[1180715]={'HV 1454:53.58,67.13 1455:35.01,68.17'}	-- Holly Preserver
G[1180717]={'HQ 1451:25.74,90.86'}	-- The Scarab Gong
G[1180743]={'1454:52.22,68.98 1455:33.85,65.70'}	-- Carefully Wrapped Present
G[1180746]={'1454:52.02,69.30 1455:33.44,65.57'}	-- Gently Shaken Gift
G[1180747]={'1454:52.08,69.67 1455:33.76,66.24'}	-- Gaily Wrapped Present
G[1180748]={'1454:52.15,69.23 1455:33.84,66.65'}	-- Ticking Present
G[1180793]={'1454:52.35,69.14 1455:33.86,65.87'}	-- Festive Gift
G[1180918]={'1941:48.16,46.31'}
G[1181011]={'1941:69.24,52.10'}
G[1181073]={'1416:89.41,75.06'}	-- Fragrant Cauldron
G[1181147]={'1942:48.33,31.66'}	-- Wanted Poster
G[1181150]={'1942:79.63,17.58'}
G[1181153]={'1942:72.23,31.18'}
G[1181698]={'1942:43.28,16.86'}
G[1181748]={'1943:50.51,11.58'}
G[100001307]={'D:100,478,97,448 Q:123'}	-- Gold Pickup Schedule
G[100001357]={'D:126,127,171,391,456,458,513,515,517,519,520 Q:136'}	-- Captain Sander's Map
G[100001962]={'D:429,431,432,433,434,568,579,703,947 Q:178'}	-- Glowing Shadowhide Pendant
G[100001972]={'D:6846,6927,116,474 Q:184'}	-- Westfall Deed
G[100002794]={'D:771,205,920,203,533,898,48,215,218 Q:337','Drops from most Duskwood mobs'}	-- An Old History Book
G[100002839]={'D:1520,1522,1523 Q:361'}	-- A Letter to Yvette
G[100002874]={'D:639 Q:373'}	-- An Unsent Letter
G[100003317]={'D:1944,1939,1940,1942,1943 Q:460'}	-- A Talking Head
G[100003668]={'D:2434 Q:522'}	-- Assassin's Contract
G[100003706]={'FA D:1001765 Q:551'}	-- Ensorcelled Parchment
G[100004056]={'1434:29.30,88.59 1434:29.30,88.59 1434:33.40,88.17'}	-- Cortello's Riddle
G[100004098]={'D:1002560 Q:594'}	-- Carefully Folded Note
G[100004433]={'FA 1417:44.29,92.88','Underwater, held by a dead dwarf'}	-- Sully Balloo's Letter
G[100004613]={'FA ','No longer dropped'}	-- Corroded Black Box
G[100004614]={'','World drop from level 34 to 40 NPCs.'}	-- Pendant of Myzrael
G[100004851]={'1412:63.25,82.69'}	-- Dirt-stained Map
G[100004854]={'D:3056 Q:770'}	-- Demon Scarred Cloak
G[100004881]={'D:1003239 Q:830'}	-- Aged Envelope
G[100004903]={'D:3204 Q:832'}	-- Eye of Burning Shadow
G[100004926]={'D:1003238 Q:819'}
G[100005099]={'D:3474 Q:883'}
G[100005102]={'D:3473 Q:884'}
G[100005103]={'D:3472 Q:885'}
G[100005138]={'D:3253 Q:897'}	-- Harvester's Head
G[100005179]={'D:3535 Q:927'}	-- Moss-twined Heart
G[100005352]={'D:2338,2339 Q:968'}	-- Book: The Powers Below
G[100005791]={'1441:30.72,24.34'}	-- Henrig Lonebrow's Journal
G[100006196]={'D:5477 Q:1392'}	-- Noboru's Cudgel
G[100006775]={'D:6171 Q:1641'}	-- Tome of Divinity (Human Paladin)
G[100006776]={'D:6171,6179 Q:1649'}	-- Tome of Valor
G[100006916]={'D:6179 Q:1645'}	-- Tome of Divinity (Dwarf Paladin)
G[100008524]={'FH Preowned Q:654'}	-- Model 4711-FTZ Power Source
G[100008623]={'D:5469,7797,7606,7269,7608,7605,5459,5475,5647,7858 Q:351',"Can drop off most NPCs in Tanaris and Zul'Farrak"}	-- OOX-17/TN Distress Beacon
G[100008704]={'D:8216,2693,2643,4465,2640,2645,2694,2648 Q:485','Can drop off most NPCs in The Hinterlands'}	-- OOX-09/HL Distress Beacon
G[100009254]={'D:7855,7856,7857,7858,15685 Q:2882',"Map parts from Pirate's Footlockers"}
G[100010000]={'D:5833 Q:3181'}	-- Margol's Horn
G[100010621]={'D:5797 Q:3513'}	-- Runed Scroll
G[100011668]={'D:10648 Q:939'}	-- Flute of Xavaric
G[100011818]={'D:15692,8566,5840,5844,8504,5846 Q:4451'}	-- Grimesilt Outhouse Key
G[100012558]={'D:7452,7453,7454 Q:4882'}	-- Blue-feathered Necklace
G[100012564]={'D:10617 Q:4881'}	-- Assassination Note
G[100012771]={'D:7438,7439,7440,7441,7442,10916 Q:5083'}	-- Empty Firewater Flask
G[100012842]={'D:10738 Q:5123'}	-- Crudely-written Log
G[100013140]={'D:7114,7118,7120,9862,14522 Q:5202'}	-- Blood Red Key
G[100014646]={'Preowned Q:5805'}	-- only available to owners who have bought WoW Collector's Edition
G[100014647]={'Preowned Q:5841'}	-- only available to owners who have bought WoW Collector's Edition
G[100014648]={'Preowned Q:8542'}	-- only available to owners who have bought WoW Collector's Edition
G[100014649]={'Preowned Q:5843'}	-- only available to owners who have bought WoW Collector's Edition
G[100014650]={'Preowned Q:8544'}	-- only available to owners who have bought WoW Collector's Edition
G[100014651]={'Preowned Q:5847'}	-- only available to owners who have bought WoW Collector's Edition
G[100016303]={'D:12678 Q:184'}
G[100016304]={'D:12677 Q:24'}
G[100016305]={'D:12676 Q:2'}
G[100016408]={'D:12759 Q:1918'}	-- Befouled Water Globe
G[100016782]={'D:12876 Q:6922'}	-- Strange Water Globe
G[100016790]={'D:4802 Q:6564'}	-- Damp Note
G[100017126]={'D:332,918,3328,4163,4214,4215,4582,4583,5165,5166,5167,6467 Q:6681'}
G[100018597]={'FH Preowned Q:172,910,911,915,925,1800,5502'}	-- Orcish Orphan Whistle
G[100018598]={'FA Preowned Q:171,558,1468,1479,1558,1687,4882'}	-- Human Orphan Whistle
G[100018950]={'D:14636 Q:7704'}	-- Chambermaid Pillaclencher's Pillow *** Not in game yet
G[100018987]={'D:9046 Q:7761','Blackrock Mountain'}	-- Blackhand's Command
G[100019228]={'Preowned Q:7907'}	-- Beasts Deck
G[100019257]={'Preowned Q:7928'}	-- Warlords Deck
G[100019267]={'Preowned Q:7929'}	-- Elementals Deck
G[100019277]={'Preowned Q:7927'}	-- Portals Deck
G[100019423]={'D:14822 Q:7937'}	-- Sayge's Fortune #23
G[100019424]={'D:19424 Q:7938'}	-- Sayge's Fortune #24
G[100019443]={'D:14822 Q:7944'}	-- Sayge's Fortune #25
G[100019452]={'D:19452 Q:7945'} -- Sayge's Fortune #27
G[100020310]={'D:4663,4664,4665,4666,4667,4668,4705,13019 Q:1480'}	-- Flayed Demon Skin
G[100020483]={'D:15298 Q:8338'}	-- Tainted Arcane Silver
G[100020741]={'D:7156,7157,7158 Q:8470'}	-- Deadwood Ritual Totem
G[100020742]={'D:7438,7439,7440,7441,7442,10916,10738 Q:8471'}	-- Winterfall Ritual Totem
G[100020949]={'D:6109 Q:8575','Talk to Azuregos'}	-- Magical Ledger - given by Azuregos at start of quest
G[100021776]={'D:15670 Q:8887'}
G[100022597]={'D:16314 Q:9175'}
G[100023179]={'1454:42.26,34.45'}	-- Flame of Orgrimmar
G[100023180]={'1456:21.22,27.05'}	-- Flame of Thunder Bluff
G[100023181]={'1458:65.87,37.25'}	-- Flame of the Undercity
G[100023182]={'1453:38.96,61.49'}	-- Flame of Stormwind
G[100023183]={'1455:64.24,24.75'}	-- Flame of Ironforge
G[100023184]={'1438:56.64,92.26'}	-- Flame of Darnassus
G[100023228]={'D:15409 Q:8474'}
G[100023249]={'D:15407 Q:9360'}
G[100024414]={'D:16522 Q:9798'}
end
-- BCC changes
if release >= 38835 and interface >= 20501 then
G[3880]={'FA 1440:86.03,44.11'} -- Sentinel Melyria Frostshadow - moved to Forest Song
G[3901]={'FA 1440:87.09,43.50'} -- Illiyana - moved to Forest Song
G[4456]={'FA 1439:33.77,42.37'}	-- Fiora Longears - moved to Auberdine
end

-- End of NPCs
